import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.PrintWriter;
import java.util.HashSet;
import java.util.Set;
import java.util.StringTokenizer;

public class Cube implements Runnable {
    Set<String> seen;

    private void solve() throws IOException {
        String s = nextToken();
        seen = new HashSet<String>();
        rec(s, 0, new StringBuilder(), new boolean[6]);
        writer.println(seen.size());
    }

    private void rec(String s, int at, StringBuilder got, boolean[] used) {
        if (at >= 6) {
            seen.add(genSmallestRotation(got.toString()));
            return;
        }
        for (int i = 0; i < 6; ++i) if (!used[i]) {
            used[i] = true;
            got.append(s.charAt(i));
            rec(s, at + 1, got, used);
            got.deleteCharAt(got.length() - 1);
            used[i] = false;
        }
    }

    String rotFront(String source) {
        StringBuilder res = new StringBuilder();
        res.append(source.charAt(3));
        res.append(source.charAt(0));
        res.append(source.charAt(1));
        res.append(source.charAt(2));
        res.append(source.charAt(4));
        res.append(source.charAt(5));
        return res.toString();
    }

    String rotRight(String source) {
        StringBuilder res = new StringBuilder();
        res.append(source.charAt(0));
        res.append(source.charAt(5));
        res.append(source.charAt(2));
        res.append(source.charAt(4));
        res.append(source.charAt(1));
        res.append(source.charAt(3));
        return res.toString();
    }

    String genSmallestRotation(String source) {
        String res = tryFour(source);
        for (int i = 0; i < 4; ++i) {
            source = rotFront(source);
            res = getMin(res, tryFour(source));
        }
        source = rotRight(source);
        for (int i = 0; i < 4; ++i) {
            source = rotFront(source);
            res = getMin(res, tryFour(source));
        }
        return res;
    }

    private String getMin(String a, String b) {
        if (a.compareTo(b) < 0)
            return a;
        else
            return b;
    }

    private String tryFour(String source) {
        String res = source;
        for (int i = 0; i < 4; ++i) {
            source = rotRight(source);
            res = getMin(res, source);
        }
        return res;
    }

    public static void main(String[] args) {
        new Cube().run();
    }

    BufferedReader reader;
    StringTokenizer tokenizer;
    PrintWriter writer;

    public void run() {
        try {
            reader = new BufferedReader(new InputStreamReader(System.in));
            tokenizer = null;
            writer = new PrintWriter(System.out);
            solve();
            reader.close();
            writer.close();
        } catch (Exception e) {
            e.printStackTrace();
            System.exit(1);
        }
    }

    int nextInt() throws IOException {
        return Integer.parseInt(nextToken());
    }

    long nextLong() throws IOException {
        return Long.parseLong(nextToken());
    }

    double nextDouble() throws IOException {
        return Double.parseDouble(nextToken());
    }

    String nextToken() throws IOException {
        while (tokenizer == null || !tokenizer.hasMoreTokens()) {
            tokenizer = new StringTokenizer(reader.readLine());
        }
        return tokenizer.nextToken();
    }
}

----

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.StringTokenizer;

public class Coffin implements Runnable {
    private void solve() throws IOException {
        int a = nextInt();
        int b = nextInt();
        int l = nextInt();
        if (l <= a || l <= b) {
            writer.println(Math.min(l, Math.min(a, b)));
            return;
        }
        double[] koef = new double[5];
        koef[4] = -a - l;
        koef[3] = -2 * b;
        koef[2] = 6 * l;
        koef[1] = -2 * b;
        koef[0] = a - l;
        List<Double> zeroes = findZeroes(koef);
        zeroes.add(0.0);
        zeroes.add(1.0);
        double res = l;
        for (double u : zeroes) {
            double cur = b * (1 - u * u) / (1 + u * u) + a * 2 * u / (1 + u * u) - l * 2 * u * (1 - u * u) / (1 + u * u) / (1 + u * u);
            res = Math.min(res, cur);
        }
        if (res < 0.5e-7) {
            writer.println("My poor head =(");
        } else {
            writer.println(res);
        }
    }

    private double eval(double[] koef, double x) {
        double res = 0.0;
        for (int i = koef.length - 1; i >= 0; --i) {
            res = res * x + koef[i];
        }
        return res;
    }

    private List<Double> findZeroes(double[] koef) {
        List<Double> res = new ArrayList<Double>();
        if (koef.length == 3) {
            double a = koef[2];
            double b = koef[1];
            double c = koef[0];
            double d = b * b - 4 * a * c;
            if (d < 0) {
                return res;
            }
            d = Math.sqrt(d);
            double sol = (-b + d) / (2 * a);
            if (sol > 0.0 && sol < 1.0) res.add(sol);
            sol = (-b - d) / (2 * a);
            if (sol > 0.0 && sol < 1.0) res.add(sol);
            Collections.sort(res);
            return res;
        }
        double[] deriv = new double[koef.length - 1];
        for (int i = 1; i < koef.length; ++i)
            deriv[i - 1] = i * koef[i];
        List<Double> derivZeroes = findZeroes(deriv);
        derivZeroes.add(0.0);
        derivZeroes.add(1.0);
        Collections.sort(derivZeroes);
        double[] val = new double[derivZeroes.size()];
        for (int i = 0; i < derivZeroes.size(); ++i) {
            double x = derivZeroes.get(i);
            val[i] = eval(koef, x);
            if (val[i] == 0) res.add(x);
        }
        for (int i = 0; i + 1 < val.length; ++i) {
            if (val[i] * val[i + 1] < 0) {
                double left = derivZeroes.get(i);
                double right = derivZeroes.get(i + 1);
                int j;
                for (j = 0; j < 200; ++j) {
                    double middle = (left + right) / 2;
                    double v = eval(koef, middle);
                    if (v == 0) {
                        res.add(middle);
                        break;
                    }
                    if (v * val[i] < 0)
                        right = middle;
                    else
                        left = middle;
                }
                if (j == 200) {
                    res.add((left + right) / 2);
                }
            }
        }
        Collections.sort(res);
        return res;
    }

    public static void main(String[] args) {
        new Coffin().run();
    }

    BufferedReader reader;
    StringTokenizer tokenizer;
    PrintWriter writer;

    public void run() {
        try {
            reader = new BufferedReader(new InputStreamReader(System.in));
            tokenizer = null;
            writer = new PrintWriter(System.out);
            solve();
            reader.close();
            writer.close();
        } catch (Exception e) {
            e.printStackTrace();
            System.exit(1);
        }
    }

    int nextInt() throws IOException {
        return Integer.parseInt(nextToken());
    }

    long nextLong() throws IOException {
        return Long.parseLong(nextToken());
    }

    double nextDouble() throws IOException {
        return Double.parseDouble(nextToken());
    }

    String nextToken() throws IOException {
        while (tokenizer == null || !tokenizer.hasMoreTokens()) {
            tokenizer = new StringTokenizer(reader.readLine());
        }
        return tokenizer.nextToken();
    }
}

----

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.List;
import java.util.StringTokenizer;

public class Monks implements Runnable {
    int[] d;
    int[][] stacks;
    int[] sp;
    int[] frozen;
    List<String> moves = new ArrayList<String>();

    private void solve() throws IOException {
        int n = nextInt();
        d = new int[n];
        for (int i = 0; i < n; ++i) {
            d[i] = nextInt();
        }
        stacks = new int[3][n];
        sp = new int[3];
        for (int i = 0; i < n; ++i) {
            stacks[0][i] = i;
        }
        sp[0] = n;
        frozen = new int[3];
        moves = new ArrayList<String>();
        doit(0, 2, false);
        if (sp[2] != n) throw new RuntimeException();
        for (int i = 0; i < n; ++i)
            if (stacks[2][i] != i) throw new RuntimeException();
        writer.println(moves.size());
        for (String x : moves) writer.println(x);
    }

    private void doit(int src, int dst, boolean mayReverse) {
        if (frozen[src] == sp[src])
            return;
        int what = d[stacks[src][frozen[src]]];
        int cnt = 0;
        while (frozen[src] < sp[src] && d[stacks[src][frozen[src]]] == what) {
            ++cnt;
            ++frozen[src];
        }
        if (cnt == 1 || mayReverse) {
            doit(src, 3 - src - dst, true);
            frozen[src] -= cnt;
            for (int i = 0; i < cnt; ++i)
                moveIt(src, dst);
            frozen[dst] += cnt;
            doit(3 - src - dst, dst, true);
            frozen[dst] -= cnt;
        } else if (frozen[src] == sp[src]) {
            frozen[src] -= cnt;
            for (int i = 0; i < cnt - 1; ++i)
                moveIt(src, 3 - src - dst);
            moveIt(src, dst);
            for (int i = 0; i < cnt - 1; ++i)
                moveIt(3 - src - dst, dst);
        } else {
            doit(src, dst, true);
            frozen[src] -= cnt;
            for (int i = 0; i < cnt; ++i)
                moveIt(src, 3 - src - dst);
            frozen[3 - src - dst] += cnt;
            doit(dst, src, true);
            frozen[3 - src - dst] -= cnt;
            for (int i = 0; i < cnt; ++i)
                moveIt(3 - src - dst, dst);
            frozen[dst] += cnt;
            doit(src, dst, false);
            frozen[dst] -= cnt;
        }
    }

    private void moveIt(int src, int dst) {
        if (frozen[src] >= sp[src]) throw new RuntimeException();
        stacks[dst][sp[dst]++] = stacks[src][--sp[src]];
        moves.add((src + 1) + " " + (dst + 1));
    }

    public static void main(String[] args) {
        new Monks().run();
    }

    BufferedReader reader;
    StringTokenizer tokenizer;
    PrintWriter writer;

    public void run() {
        try {
            reader = new BufferedReader(new InputStreamReader(System.in));
            tokenizer = null;
            writer = new PrintWriter(System.out);
            solve();
            reader.close();
            writer.close();
        } catch (Exception e) {
            e.printStackTrace();
            System.exit(1);
        }
    }

    int nextInt() throws IOException {
        return Integer.parseInt(nextToken());
    }

    long nextLong() throws IOException {
        return Long.parseLong(nextToken());
    }

    double nextDouble() throws IOException {
        return Double.parseDouble(nextToken());
    }

    String nextToken() throws IOException {
        while (tokenizer == null || !tokenizer.hasMoreTokens()) {
            tokenizer = new StringTokenizer(reader.readLine());
        }
        return tokenizer.nextToken();
    }
}

----

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.PrintWriter;
import java.util.StringTokenizer;

public class Crocodile implements Runnable {
    private void solve() throws IOException {
        int m = nextInt();
        int n = nextInt();
        int mx = Math.max(n, m);
        double[][] ans = new double[mx + 1][mx + 1];
        for (int sum = 0; sum <= mx + mx; ++sum) {
            for (int a = 0; a <= mx; ++a) {
                int b = sum - a;
                if (b >= 0 && b <= mx) {
                    ans[a][b] = doit(a, b, ans);
                }
            }
        }
        writer.println(ans[m][n] + " " + (1.0 - ans[m][n]));
    }

    private double doit(int m, int n, double[][] ans) {
        double res = 1.0 / (n + 1);
        if (m == 0 || n == 0) return res;
        double borderP = 1 / (ans[n][m - 1] * (n + 1) + 1);
        res = Math.max(res, eval(m, n, ans, 0.0));
        res = Math.max(res, eval(m, n, ans, borderP));
        res = Math.max(res, eval(m, n, ans, 1.0));
        return res;
    }

    private double eval(int m, int n, double[][] ans, double p) {
        return (1 - p) * n / (n + 1.0) * (1 - ans[n - 1][m]) + (p + (1 - p) / (n + 1.0) - Math.max((1 - p) / (n + 1), p * ans[n][m - 1]));
    }

    public static void main(String[] args) {
        new Crocodile().run();
    }

    BufferedReader reader;
    StringTokenizer tokenizer;
    PrintWriter writer;

    public void run() {
        try {
            reader = new BufferedReader(new InputStreamReader(System.in));
            tokenizer = null;
            writer = new PrintWriter(System.out);
            solve();
            reader.close();
            writer.close();
        } catch (Exception e) {
            e.printStackTrace();
            System.exit(1);
        }
    }

    int nextInt() throws IOException {
        return Integer.parseInt(nextToken());
    }

    long nextLong() throws IOException {
        return Long.parseLong(nextToken());
    }

    double nextDouble() throws IOException {
        return Double.parseDouble(nextToken());
    }

    String nextToken() throws IOException {
        while (tokenizer == null || !tokenizer.hasMoreTokens()) {
            tokenizer = new StringTokenizer(reader.readLine());
        }
        return tokenizer.nextToken();
    }
}