#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <time.h>

#define LMAX 10000

char line[LMAX];
int pozline = 0, lenline = 0;

inline void ReadInt(int *x) {
    while (pozline < lenline && (line[pozline] < '0' || line[pozline] > '9'))
        pozline++;
 
    if (pozline == lenline) {
        fgets(line, LMAX - 3, stdin);
        pozline = 0;
        lenline = strlen(line);
        while (pozline < lenline && line[pozline] < '1' && line[pozline] > '9' && line[pozline] != '-')
            pozline++;
    }
     
    *x = 0;
    while (line[pozline] >= '0' && line[pozline] <= '9') {
        *x = (*x) * 10 + (line[pozline] - '0');
        pozline++;
    }   
}

#define NMAX 100100

int vec[2 * NMAX][3], nvec[2 * NMAX];
int N;

void ReadInput() {
	int k, a, b;

	freopen("circulatie.in", "r", stdin);
	ReadInt(&N);

	memset(nvec, 0, sizeof(nvec));
	for (k = 3 * N; k >= 1; k--) {
		ReadInt(&a); ReadInt(&b);
		b += N;
		vec[a][nvec[a]] = b;
		nvec[a]++;
		vec[b][nvec[b]] = a;
		nvec[b]++;
	}
}

char visited[2 * NMAX], flow[2 * NMAX][3], nflow[2 * NMAX], tip[2 * NMAX];
int q[2 * NMAX], parent[2 * NMAX], pflow[2 * NMAX], reachable[NMAX], nreachable, li, ls;

void MaxMatching(char round) {
	int i, j, k;

	memset(pflow, 0, sizeof(pflow));
	
	while (1) {
		for (i = 1; i <= 2 * N; i++) {
			visited[i] = 0;
			parent[i] = 0;
		}

		li = 0; ls = -1;
		for (i = 1; i <= N; i++) {
			if (nflow[i] < round) {
				visited[i] = 1;
				ls++;
				q[ls] = i;
			}
		}

		while (li <= ls) {
			i = q[li];
			li++;

			if (i <= N) {
				for (k = 0; k < 3; k++)
					if (!flow[i][k]) {
						j = vec[i][k];
						if (!visited[j]) {
							visited[j] = 1;
							tip[j] = 1;
							parent[j] = i;
							ls++;
							q[ls] = j;
						}
					}
			} else {
				if (pflow[i] > 0 && !visited[pflow[i]]) {
					visited[pflow[i]] = 1;
					tip[pflow[i]] = 2;
					parent[pflow[i]] = i;
					ls++;
					q[ls] = pflow[i];
				}
			}
		}
		
		// Find all the reachable nodes from the second set.
		nreachable = 0;
		for (i = N + 1; i <= 2 * N; i++)
			if (visited[i] && nflow[i] < round) {
				reachable[nreachable] = i;
				nreachable++;
			}
		
		if (nreachable == 0)
			break;

		// Increase the flow on multiple disjoint paths.
		for (i = 1; i <= 2 * N; i++)
			visited[i] = 0;
		
		for (k = 0; k < nreachable; k++) {
			i = reachable[k];
			
			// Check that all the nodes on the augmenting path have not been visited.
			while (i > 0) {
				if (visited[i])
					break;
				i = parent[i];
			}
			
			if (i > 0)
				continue;
			
			i = reachable[k];
			nflow[i]++;
			while (i > 0) {
				visited[i] = 1;

				if (parent[i] == 0) {
					nflow[i]++;
					break;
				}

				if (tip[i] == 1) {
					for (j = 0; j < 3; j++)
						if (vec[parent[i]][j] == i) {
							flow[parent[i]][j] = round;
							break;
						}
					
					pflow[i] = parent[i];
				} else {
					for (j = 0; j < 3; j++)
						if (vec[i][j] == parent[i]) {
							flow[i][j] = 0;
							break;
						}
				}
				
				i = parent[i];
			}
		}
	}	
}

void WriteOutput() {
	int i, k;
	
	freopen("circulatie.out", "w", stdout);
	for (i = 1; i <= N; i++) {
		for (k = 0; k < 3; k++)
			if (flow[i][k] <= 1)
				printf("%d %d %d\n", i, vec[i][k] - N, flow[i][k] + 1);
			else
				printf("%d %d -3\n", i, vec[i][k] - N);
	}
}

int main() {
	int tstart = clock();

	ReadInput();

	memset(flow, 0, sizeof(flow));
	memset(nflow, 0, sizeof(nflow));
	
	MaxMatching(1);	
	MaxMatching(2);

	WriteOutput();

	fprintf(stderr, "Duration=%.3lf sec\n", (double) (clock() - tstart) / CLOCKS_PER_SEC);
	return 0;
}
