// Mugurel Ionut Andreica
// Time complexity: O(N+M+E*(H+N/H)) = approx. O(N+M+E*sqrt(N)) when H is approx. sqrt(N).
// Actually, it all depends on the number of critical edges in the original graph.
// If there are C critical edges in the original graph then the time complexity is
// O(N+M+E*(H+C/H)).

#include <stdio.h>
#include <string.h>
#include <vector>
#include <queue>
#include <map>

using namespace std;

#define NMAX 100100
#define MMAX 200100

#define H 175

int N, E;
vector<int> vec[NMAX];
map<pair<int, int>, int> cnt;
int ei[MMAX], ej[MMAX];
double p[MMAX];

void ReadInput() {
	int i, j, M;
	freopen("critice2.in", "r", stdin);
	scanf("%d %d", &N, &M);
	
	while (M--) {
		scanf("%d %d", &i, &j);
		vec[i].push_back(j);
		vec[j].push_back(i);
		cnt[make_pair(i, j)]++;
		cnt[make_pair(j, i)]++;
	}
	
	scanf("%d", &E);
	for (i = 1; i <= E; i++) {
		scanf("%d %d %lf", &ei[i], &ej[i], &p[i]);
	}
}

char visited[NMAX];
int vidx[NMAX];
int parent[NMAX], level[NMAX], minlevel[NMAX], c[NMAX], stk[NMAX], niv, ncomp;

void DFS() {
	visited[stk[niv]] = 1;
	level[stk[niv]] = minlevel[stk[niv]] = niv;
	for (vidx[stk[niv]] = 0; vidx[stk[niv]] < vec[stk[niv]].size(); vidx[stk[niv]]++) {
		if (!visited[vec[stk[niv]][vidx[stk[niv]]]]) {
			parent[vec[stk[niv]][vidx[stk[niv]]]] = stk[niv];
			stk[niv + 1] = vec[stk[niv]][vidx[stk[niv]]];
			niv++;
			DFS();
			niv--;
			if (minlevel[vec[stk[niv]][vidx[stk[niv]]]] < minlevel[stk[niv]])
				minlevel[stk[niv]] = minlevel[vec[stk[niv]][vidx[stk[niv]]]];

			if (minlevel[vec[stk[niv]][vidx[stk[niv]]]] > level[stk[niv]] &&
				cnt[make_pair(stk[niv], vec[stk[niv]][vidx[stk[niv]]])] == 1) {
				//fprintf(stderr, "critical edge: %d %d\n", stk[niv], vec[stk[niv]][vidx[stk[niv]]]);
				ncomp++;
				c[vec[stk[niv]][vidx[stk[niv]]]] = ncomp;
			}
		} else if (vec[stk[niv]][vidx[stk[niv]]] != parent[stk[niv]]) {
			if (level[vec[stk[niv]][vidx[stk[niv]]]] < minlevel[stk[niv]]) {
				minlevel[stk[niv]] = level[vec[stk[niv]][vidx[stk[niv]]]];
			}
		}
	}
}

queue<int> q;

void ExpandComponents() {
	int x, i, j, k;
	memset(visited, 0, sizeof(visited));
	for (x = 1; x <= N; x++)
		if (c[x] > 0 && !visited[x]) {
			q.push(x);
			visited[x] = 1;
			while (q.size() > 0) {
				i = q.front();
				q.pop();
				for (k = 0; k < vec[i].size(); k++) {
					j = vec[i][k];
					if (!visited[j] && c[j] == 0 && j != parent[i]) {
						visited[j] = 1;
						c[j] = c[x];
						q.push(j);
					}
				}
			}
		}

	//for (x = 1; x <= N; x++)
	//	fprintf(stderr, "x=%d c=%d\n", x, c[x]);
}

int pt[NMAX][2];
vector<int> child[NMAX];

void ConstructTree() {
	int i, j, k;
	for (i = 1; i <= N; i++)
		for (k = 0; k < vec[i].size(); k++) {
			j = vec[i][k];
			if (c[i] != c[j] && j == parent[i]) {
				pt[c[i]][0] = c[j];
				//fprintf(stderr, "tree edge: %d %d\n", c[i], c[j]);
				child[c[j]].push_back(c[i]);
			}
		}
}

int hniv;
double ppt[NMAX][2];

void DFSTree() {
	if (niv > 0) {
		hniv = ((niv - 1) / H) * H;
		pt[stk[niv]][1] = stk[hniv];
		//fprintf(stderr, "tree super-edge: %d %d\n", stk[niv], stk[hniv]);
	}

	level[stk[niv]] = niv;
	ppt[stk[niv]][0] = ppt[stk[niv]][1] = 1.0;
	
	for (vidx[stk[niv]] = 0; vidx[stk[niv]] < child[stk[niv]].size(); vidx[stk[niv]]++) {
		stk[niv + 1] = child[stk[niv]][vidx[stk[niv]]];
		niv++;
		DFSTree();
		niv--;
	}
}

void ProcessEdges() {
	int eidx, i, j;
	for (eidx = 1; eidx <= E; eidx++) {
		p[eidx] = 1.0 - p[eidx];
		i = ei[eidx]; j = ej[eidx];
		
		//fprintf(stderr, "eidx=%d/%d i=%d j=%d\n", eidx, E, i, j);
		i = c[i];
		j = c[j];
		//fprintf(stderr, "i=%d j=%d\n", i, j);
		
		while (i != j) {
			if (pt[i][1] == pt[j][1] || !pt[i][1] || !pt[j][1])
				break;
			if (level[pt[i][1]] >= level[pt[j][1]]) {
				ppt[i][1] *= p[eidx];
				i = pt[i][1];
			} else {
				ppt[j][1] *= p[eidx];
				j = pt[j][1];
			}
		}
		
		while (i != j) {
			//fprintf(stderr, "i=%d(%d,%d) j=%d(%d,%d)\n", i, level[i], pt[i][0], j, level[j], pt[j][0]);
			if (i == 0 || j == 0)
				break;
			
			if (level[i] >= level[j]) {
				ppt[i][0] *= p[eidx];
				i = pt[i][0];
			} else {
				ppt[j][0] *= p[eidx];
				j = pt[j][0];
			}
		}
	}
}

double pcritical[NMAX], answer;

void ComputeAnswer() {
	int i, j;
	for (i = 2; i <= ncomp; i++)
		pcritical[i] = 1.0;
	
	for (i = 2; i <= ncomp; i++) {
		pcritical[i] *= ppt[i][0];
		j = i;
		while (j != pt[i][1]) {
			pcritical[j] *= ppt[i][1];
			j = pt[j][0];
		}
	}
	
	answer = 0.0;
	for (i = 2; i <= ncomp; i++) {
		//fprintf(stderr, "i=%d pcritical=%.6lf\n", i, pcritical[i]);
		answer += pcritical[i];
	}
}

void WriteAnswer() {
	freopen("critice2.out", "w", stdout);
	printf("%.7lf\n", answer);
}

int main() {
	ReadInput();

	memset(visited, 0, sizeof(visited));
	ncomp = 1;
	c[1] = 1;
	niv = 1;
	stk[niv] = 1;
	DFS();

	for (int i = 1; i <= N; i++)
		if (!visited[i])
			return 1;
	
	ExpandComponents();
	ConstructTree();
	
	niv = 0;
	stk[niv] = 1;
	DFSTree();

	//fprintf(stderr, "ncomp=%d\n", ncomp);
	
	ProcessEdges();
	ComputeAnswer();
	WriteAnswer();
	return 0;
}
