#include <stdio.h>

#define DEBUG 0
#define NMAX 1001
#define MMAX 200111
#define QMAX 1048576
#define QMOD 1048575

int start_edge[2][NMAX];
int next_edge[2][MMAX], next_node[2][MMAX], cost[2][MMAX], flux[2][MMAX], cap[2][MMAX];
int N, M, S, D;

char visited[NMAX];
int q[QMAX], li, ls;

int CanIncreaseFlow() {
	int i, j, k;
	for (i = 1; i <= N; i++)
		visited[i] = 0;
	q[li = ls = 0] = S;
	visited[S] = 1;

	while (li <= ls && !visited[D]) {
		i = q[li];
		li++;
		
		for (k = start_edge[0][i]; k > 0; k = next_edge[0][k]) {
			j = next_node[0][k];

			if (DEBUG)
				fprintf(stderr, "0: %d -> %d (cost=%d flux=%d cap=%d)\n", i, j, cost[0][k], flux[0][k], cap[0][k]);

			if (flux[0][k] < cap[0][k] && !visited[j]) {
				visited[j] = 1;
				ls++;
				q[ls] = j;
			}
		}

		for (k = start_edge[1][i]; k > 0; k = next_edge[1][k]) {
			j = next_node[1][k];

			if (DEBUG)
				fprintf(stderr, "1: %d <- %d (cost=%d flux=%d cap=%d)\n", i, j, cost[1][k], flux[1][k], cap[1][k]);

			if (flux[1][k] > 0 && !visited[j]) {
				visited[j] = 1;
				ls++;
				q[ls] = j;
			}
		}
	}

	return visited[D];
}

char inq[NMAX];
int p[NMAX], d[NMAX], ninq[NMAX];

int CanDecreaseCost() {
	int i, j, k, ninqmax = 0;

	li = ls = 0;
	for (i = 1; i <= N; i++) {
		p[i] = 0;
		d[i] = 0;
		q[ls] = i;
		ls++;
		inq[i] = 1;
		ninq[i] = 0;
	}

	while (li != ls && ninqmax <= N) {
		i = q[li];
		inq[i] = 0;
		li = (li + 1) & QMOD;
	
		if (p[i] > 0) {
			if (inq[p[i]])
				continue;
			else if (p[p[i]] > 0 && inq[p[p[i]]])
				continue;
		}
	
		for (k = start_edge[0][i]; k > 0; k = next_edge[0][k]) {
			j = next_node[0][k];

			if (flux[0][k] < cap[0][k] && d[i] + cost[0][k] < d[j]) {
				d[j] = d[i] + cost[0][k];
				p[j] = i;
				if (!inq[j]) {
					q[ls] = j;
					ls = (ls + 1) & QMOD;
					ninq[j]++;
					if (ninq[j] > ninqmax)
						ninqmax = ninq[j];
				}
			}
		}

		for (k = start_edge[1][i]; k > 0; k = next_edge[1][k]) {
			j = next_node[1][k];
			if (flux[1][k] > 0 && d[i] - cost[1][k] < d[j]) {
				d[j] = d[i] - cost[1][k];
				p[j] = i;
				if (!inq[j]) {
					q[ls] = j;
					ls = (ls + 1) & QMOD;
					ninq[j]++;
					if (ninq[j] > ninqmax)
						ninqmax = ninq[j];
				}
			}
		}
	}
	
	if (DEBUG)
		fprintf(stderr, "ninqmax=%d\n", ninqmax);
	
	if (ninqmax > N)
		return 1;
	return 0;
}

int main() {
	int T, i, j, co, fl, ca, k;

	freopen("flux2.in", "r", stdin);
	freopen("flux2.out", "w", stdout);

	scanf("%d", &T);
	
	while (T--) {
		scanf("%d %d %d %d", &N, &M, &S, &D);
		for (i = 1; i <= N; i++)
			start_edge[0][i] = start_edge[1][i] = 0;

		for (k = 1; k <= M; k++) {
			scanf("%d %d %d %d %d", &i, &j, &co, &fl, &ca);
			cost[0][k] = cost[1][k] = co;
			flux[0][k] = flux[1][k] = fl;
			cap[0][k] = cap[1][k] = ca;
			next_node[0][k] = j;
			next_node[1][k] = i;
			next_edge[0][k] = start_edge[0][i];
			next_edge[1][k] = start_edge[1][j];
			start_edge[0][i] = start_edge[1][j] = k;
		}

		if (DEBUG)
			fprintf(stderr, "New test\n");

		if (CanIncreaseFlow() || CanDecreaseCost())
			printf("0\n");
		else
			printf("1\n");
	}
	
	return 0;
}
