#include <stdio.h>
#include <math.h>
#include <algorithm>
#include <vector>

using namespace std;

#define NMAX 1111
#define eps 1e-10

double X1[NMAX], X2[NMAX], Y1[NMAX], Y2[NMAX];
int N;

void ReadInput() {
	int i;
	freopen("taie.in", "r", stdin);
	scanf("%d", &N);
	for (i = 0; i < N; i++)
		scanf("%lf %lf %lf %lf", &X1[i], &Y1[i], &X2[i], &Y2[i]);
}

double XA, YA, XB, YB, pi;
bool answer;
vector<pair<double, int> > vu;

bool Test(double Xc, double Yc, int idx) {
	int i, nopen;
	double u1, u2, tmp, umin = -pi, umax = pi;

	//fprintf(stderr, "Testing %.6lf %.6lf %d\n", Xc, Yc, idx);
	vu.clear();
	
	for (i = 0; i < N; i++) {
		if (i == idx)
			continue;
		u1 = atan2(Y1[i] - Yc, X1[i] - Xc);
		u2 = atan2(Y2[i] - Yc, X2[i] - Xc);
		if (u1 > u2) {
			tmp = u1;
			u1 = u2;
			u2 = tmp;
		}
		
		if (u2 - u1 > pi) {
			tmp = u1 + pi;
			u1 = u2 - pi;
			u2 = tmp;
		}

		if (u1 > umin)
			umin = u1;
		if (u2 < umax)
			umax = u2;
		
		//fprintf(stderr, "    i=%d u1=%.9lf u2=%.9lf\n", i, u1, u2);
		vu.push_back(make_pair(u1, -1));
		vu.push_back(make_pair(u2, +1));

		if (fabs(u1) < eps) {
			vu.push_back(make_pair(u1 - pi, -1));
			vu.push_back(make_pair(u2 - pi, +1));
			vu.push_back(make_pair(u1 + pi, -1));
			vu.push_back(make_pair(u2 + pi, +1));
			//fprintf(stderr, "    i=%d u1'=%.9lf u2'=%.9lf\n", i, u1 - pi, u2 - pi);
			//fprintf(stderr, "    i=%d u1''=%.9lf u2''=%.9lf\n", i, u1 + pi, u2 + pi);
		} else if (u1 > 0.0) {
			vu.push_back(make_pair(u1 - pi, -1));
			vu.push_back(make_pair(u2 - pi, +1));
			//fprintf(stderr, "    i=%d u1'=%.9lf u2'=%.9lf\n", i, u1 - pi, u2 - pi);
		} else {
			vu.push_back(make_pair(u1 + pi, -1));
			vu.push_back(make_pair(u2 + pi, +1));
			//fprintf(stderr, "    i=%d u1'=%.9lf u2'=%.9lf\n", i, u1 + pi, u2 + pi);
		}
	}

	if (umin <= umax) {
		answer = true;
	} else {
		sort(vu.begin(), vu.end());
		nopen = 0;
		for (i = 0; i < vu.size(); i++) {
			if (vu[i].second < 0)
				nopen++;
			else
				nopen--;
			if (nopen == N - 1)
				break;
		}
	
		if (nopen == N - 1) {
			answer = true;
			umin = vu[i].first;
			umax = vu[i + 1].first;
		}
	}
	
	if (answer) {
		XA = Xc;
		YA = Yc;
		u1 = 0.5 * (umin + umax);
		XB = Xc + 1000.0 * cos(u1);
		YB = Yc + 1000.0 * sin(u1);
		return true;
	} else
		return false;
}

void Solve() {
	int i;
	answer = false;
	pi = 2.0 * acos(0.0);
	
	for (i = 0; i < N; i++) {
		if (Test(X1[i], Y1[i], i))
			break;
		if (Test(X2[i], Y2[i], i))
			break;		
	}
}

void WriteAnswer() {
	//freopen("taie.out", "w", stdout);
	if (!answer)
		printf("-1\n");
	else
		printf("%.9lf %.9lf %.9lf %.9lf\n", XA, YA, XB, YB);
}

int main() {
	int tstart = clock();
	ReadInput();
	Solve();
	WriteAnswer();
	fprintf(stderr, "Duration=%.3lf sec\n", (double) (clock() - tstart) / CLOCKS_PER_SEC);
	return 0;
}
