import java.util.*;
import java.io.*;

public class colorful_as {
    class Edge {
        int s;
        int t;
        int c;
        int f;
        Edge r;
        EdgeDesc desc;

        public Edge(int s, int t, int c, EdgeDesc desc) {
            this.s = s;
            this.t = t;
            this.c = c;
            this.f = 0;
            this.desc = desc;
        }
    }

    class EdgeDesc {
        int s;
        int t;

        public EdgeDesc(int s, int t) {
            this.s = s;
            this.t = t;
        }
    }

    class Graph {
        int n;
        ArrayList<Edge> edges[];

        public Graph(int n) {
            this.n = n;
            edges = new ArrayList[n];
            for (int i = 0; i < n; i++) {
                edges[i] = new ArrayList<Edge>();
            }
        }

        void addEdge(int s, int t, int c) {
            Edge ef = new Edge(s, t, c, null);
            Edge er = new Edge(t, s, 0, null);
            ef.r = er;
            er.r = ef;
            edges[s].add(ef);
            edges[t].add(er);
        }

        void addEdge(int s, int t, int c, EdgeDesc desc) {
            Edge ef = new Edge(s, t, c, desc);
            Edge er = new Edge(t, s, 0, null);
            ef.r = er;
            er.r = ef;
            edges[s].add(ef);
            edges[t].add(er);
        }

        boolean[] u;

        int dfs(int i, int t, int c) {
            if (i == t) {
                return c;
            }
            u[i] = true;

            for (Edge e : edges[i]) {
                if (e.f < e.c && !u[e.t]) {
                    int cap = dfs(e.t, t, Math.min(c, e.c - e.f));
                    if (cap > 0) {
                        e.f += cap;
                        e.r.f -= cap;
                        return cap;
                    }
                }
            }

            return 0;
        }

        int maxFlow(int s, int t) {
            u = new boolean[n];

            int flow = 0;
            while (true) {
                Arrays.fill(u, false);
                int df = dfs(s, t, Integer.MAX_VALUE);
                if (df == 0) {
                    break;
                }
                flow += df;
            }

            return flow;
        }
    }


    int m;
    int n;
    int k;

    int getSource() {
        return 2 * n + 8 * n * k;
    }

    int getSink() {
        return 2 * n + 8 * n * k + 1;
    }

    int getCenterL(int i) {
        return i;
    }

    int getCenterR(int i) {
        return n + i;
    }

    int getXL(int i, int j) {
        return 2 * n + 0 * n * k + i * k + j;
    }

    int getYL(int i, int j) {
        return 2 * n + 1 * n * k + i * k + j;
    }

    int getZL(int i, int j) {
        return 2 * n + 2 * n * k + i * k + j;
    }

    int getWL(int i, int j) {
        return 2 * n + 3 * n * k + i * k + j; 
    }

    int getXR(int i, int j) {
        return 2 * n + 4 * n * k + 0 * n * k + i * k + j;
    }

    int getYR(int i, int j) {
        return 2 * n + 4 * n * k + 1 * n * k + i * k + j;
    }

    int getZR(int i, int j) {
        return 2 * n + 4 * n * k + 2 * n * k + i * k + j;
    }

    int getWR(int i, int j) {
        return 2 * n + 4 * n * k + 3 * n * k + i * k + j;
    }

    public void run() throws IOException {
        Scanner in = new Scanner(new File("colorful.in"));
        PrintWriter out = new PrintWriter(new File("colorful.out"));

        n = in.nextInt();
        m = in.nextInt();
        k = in.nextInt();

        Graph g = new Graph(2 * n + 8 * n * k + 2);

        for (int i = 0; i < n; i++) {
            g.addEdge(getSource(), getCenterL(i), 2);
            g.addEdge(getCenterR(i), getSink(), 2);

            for (int j = 0; j < k; j++) {
                g.addEdge(getSource(), getXL(i, j), 2);
                g.addEdge(getYL(i, j), getSink(), 2);
                g.addEdge(getSource(), getZL(i, j), 2);
                g.addEdge(getWL(i, j), getSink(), 2);

                g.addEdge(getCenterL(i), getYL(i, j), 1);
                g.addEdge(getXL(i, j), getYL(i, j), 1);
                g.addEdge(getXL(i, j), getWL(i, (j + (k - 1)) % k), 1);
                g.addEdge(getZL(i, j), getYL(i, j), 1);
                g.addEdge(getZL(i, j), getWL(i, j), 1);

                g.addEdge(getXR(i, j), getSink(), 2);
                g.addEdge(getSource(), getYR(i, j), 2);
                g.addEdge(getZR(i, j), getSink(), 2);
                g.addEdge(getSource(), getWR(i, j), 2);

                g.addEdge(getYR(i, j), getCenterR(i), 1);
                g.addEdge(getYR(i, j), getXR(i, j), 1);
                g.addEdge(getYR(i, j), getZR(i, j), 1);
                g.addEdge(getWR(i, j), getXR(i, (j + 1) % k), 1);
                g.addEdge(getWR(i, j), getZR(i, j), 1);
            }
        }

        for (int i = 0; i < m; i++) {
            int s = in.nextInt() - 1;
            int t = (-in.nextInt()) - 1;
            int c = in.nextInt() - 1;
            g.addEdge(getXL(s, c), getXR(t, c), 1, new EdgeDesc(s, t));
        }

        int flow = g.maxFlow(getSource(), getSink());
        if (flow == 2 * n + 8 * n * k) {
            out.println("YES");
            boolean[][] b = new boolean[n][n];
            for (int i = 0; i < g.n; i++) {
                for (Edge e : g.edges[i]) {
                    if (e.desc != null && e.f == e.c) {
                        b[e.desc.s][e.desc.t] = true;
                    }
                }
            }

            ArrayList<ArrayList<Integer>> ans = new ArrayList<ArrayList<Integer>>();
            boolean[] u = new boolean[n];
            boolean[] v = new boolean[n];
            for (int i = 0; i < n; i++) {
                if (!u[i]) {
                    ArrayList<Integer> nn = new ArrayList<Integer>();
                    int t = i;
                    while (!u[t]) {
                        u[t] = true;
                        nn.add(t + 1);
                        int k = -1;
                        for (int j = 0; j < n; j++) {
                            if (b[t][j] && !v[j]) {
                                k = j;
                                break;
                            }
                        }
                        v[k] = true;
                        nn.add(-(k + 1));
                        for (int j = 0; j < n; j++) {
                            if (b[j][k] && !u[j]) {
                                t = j;
                                break;
                            }
                        }
                    }
                    ans.add(nn);
                }
            }

            out.println(ans.size());
            for (ArrayList<Integer> cyc : ans) {
                out.print(cyc.size());
                for (int x : cyc) {
                    out.print(" " + x);
                }
                out.println();
            }
        } else {
            out.println("NO");
        }

        in.close();
        out.close();
    }

    public static void main(String[] arg) throws IOException {
        new colorful_as().run();
    }
}
