import java.io.*;
import java.util.List;
import java.util.ArrayList;

/**
 * recursion_pm to be documented :TODO:
 *
 * @author Pavel Mavrin
 * @id {Id}
 */
public class recursion_pm implements Runnable {

    InputStream in;
    PrintWriter out;
    private char nextChar;
    private static final char END = 27;
    List<Procedure> procedures = new ArrayList<Procedure>();
    byte[][] visited;

    private void solve() throws Exception {
        readNext();
        readInput();
        visited = new byte[procedures.size()][];
        for (int i = 0; i < procedures.size(); i++) {
            visited[i] = new byte[(1 << procedures.get(i).args.size())];
        }
        for (int i = 0; i < procedures.size(); i++) {
            for (int j = 0; j < (1 << procedures.get(i).args.size()); j++) {
                if (dfs(i, j)) {
                    out.println("YES");
                    return;
                }
            }
        }
        out.println("NO");
    }

    private boolean dfs(int i, int j) {
        if (visited[i][j] == 2) return false;
        if (visited[i][j] == 1) return true;
        visited[i][j] = 1;
        Procedure procedure = procedures.get(i);
        int jj = j;
        boolean[] a = new boolean[procedure.args.size()];
        for (int k = a.length - 1; k >= 0; k--) {
            a[k] = (jj & 1) == 1;
            jj /= 2;
        }
        if (procedure.statement.execute(a)) {
            return true;
        }
        visited[i][j] = 2;
        return false;
    }

    private void readInput() {
        while (true) {
            skipSpaces();
            if (nextChar == END) break;
            procedures.add(readProcedure());
        }
        for (int i = 0; i < procedures.size(); i++) {
            for (int j = 0; j < i; j++) {
                assertTrue(!procedures.get(i).name.equals(procedures.get(j).name));
            }
        }
    }

    private Procedure readProcedure() {
        Procedure procedure = new Procedure();
        procedure.name = readNextToken();
        assertTrue(isIdentifier(procedure.name));
        assertTrue(readNextToken().equals("("));
        procedure.args = readArgList();
        for (int i = 0; i < procedure.args.size(); i++) {
            for (int j = 0; j < i; j++) {
                assertTrue(!procedure.args.get(i).equals(procedure.args.get(j)));
            }
        }
        procedure.statement = readStatement(procedure);
        return procedure;
    }

    private Statement readStatement(Procedure procedure) {
        String s = readNextToken();
        if (isIdentifier(s)) {
            String t = readNextToken();
            if (t.equals("++")) {
                return new IncrementStatement(findArgument(procedure, s));
            } else if (t.equals("--")) {
                return new DecrementStatement(findArgument(procedure, s));
            } else if (t.equals("(")) {
                List<String> argList = readArgList();
                int[] args = new int[argList.size()];
                for (int i = 0; i < args.length; i++) {
                    args[i] = findArgument(procedure, argList.get(i));
                }
                return new CallStatement(s, args);
            } else {
                assertTrue(false, t);
                return null;
            }
        } else if (s.equals("if")) {
            assertTrue(readNextToken().equals("("));
            String t = readNextToken();
            assertTrue(isIdentifier(t));
            assertTrue(readNextToken().equals(")"));
            Statement ifTrue = readStatement(procedure);
            assertTrue(readNextToken().equals("else"));
            Statement ifFalse = readStatement(procedure);
            return new IfStatement(findArgument(procedure, t), ifTrue, ifFalse);
        } else if (s.equals("{")) {
            List<Statement> statements = new ArrayList<Statement>();
            while (true) {
                skipSpaces();
                if (nextChar == '}') {
                    readNext();
                    break;
                }
                statements.add(readStatement(procedure));
            }
            return new BlockStatement(statements);
        } else {
            assertTrue(false);
            return null;
        }
    }

    private List<String> readArgList() {
        List<String> result = new ArrayList<String>();
        while (true) {
            String s = readNextToken();
            if (s.equals(")")) {
                assertTrue(result.size() == 0);
                break;
            }
            assertTrue(isIdentifier(s));
            result.add(s);
            s = readNextToken();
            if (s.equals(")")) break;
            assertTrue(s.equals(","));
        }
        return result;
    }

    private int findArgument(Procedure procedure, String name) {
        for (int i = 0; i < procedure.args.size(); i++) {
            if (procedure.args.get(i).equals(name)) return i;
        }
        assertTrue(false);
        return -1;
    }

    private void assertTrue(boolean b, String t) {
        if (!b) {
            System.err.println("Invalid input file: " + t);
            new Exception().printStackTrace();
            System.exit(1);
        }
    }

    private void assertTrue(boolean b) {
        assertTrue(b, "");
    }

    private boolean isIdentifier(String s) {
        if (s.length() == 0) return false;
        for (int i = 0; i < s.length(); i++) {
            if (!isIdentifierPart(s.charAt(i))) return false;
        }
        return !s.equals("if") && !s.equals("else");
    }

    private String readNextToken() {
        skipSpaces();
        if (isIdentifierPart(nextChar)) {
            String s = "";
            while (isIdentifierPart(nextChar)) {
                s += nextChar;
                readNext();
            }
            return s;
        } else {
            String s;
            if (nextChar == '+' || nextChar == '-') {
                s = "" + nextChar + readNext();
            } else {
                s = "" + nextChar;
            }
            readNext();
            return s;
        }
    }

    private boolean isIdentifierPart(char c) {
        return (c >= '0' && c <= '9') || (c >= 'a' && c <= 'z') || (c >= 'A' && c <= 'Z');
    }

    private void skipSpaces() {
        while (Character.isWhitespace(nextChar)) {
            readNext();
        }
    }

    private char readNext() {
        int i = 0;
        try {
            i = in.read();
        } catch (IOException e) {
            e.printStackTrace();
            System.exit(1);
        }
        return nextChar = i < 0 ? END : (char) i;
    }

    class Procedure {
        String name;
        List<String> args;
        Statement statement;
    }

    abstract class Statement {
        abstract public boolean execute(boolean[] args);
    }

    class IncrementStatement extends Statement {
        int variable;

        public IncrementStatement(int variable) {
            this.variable = variable;
        }

        public boolean execute(boolean[] args) {
            args[variable] = true;
            return false;
        }
    }

    class DecrementStatement extends Statement {
        int variable;

        public DecrementStatement(int variable) {
            this.variable = variable;
        }

        public boolean execute(boolean[] args) {
            args[variable] = false;
            return false;
        }
    }

    class IfStatement extends Statement {
        int variable;
        Statement ifTrue;
        Statement ifFalse;

        public IfStatement(int variable, Statement ifTrue, Statement ifFalse) {
            this.variable = variable;
            this.ifTrue = ifTrue;
            this.ifFalse = ifFalse;
        }

        public boolean execute(boolean[] args) {
            if (args[variable]) {
                return ifTrue.execute(args);
            } else {
                return ifFalse.execute(args);
            }
        }
    }

    class CallStatement extends Statement {
        String procedureName;
        int procedure;
        int[] args;

        public CallStatement(String procedureName, int[] args) {
            this.procedureName = procedureName;
            this.args = args;
            procedure = -1;
        }

        public boolean execute(boolean[] args) {
            if (procedure == -1) {
                for (int i = 0; i < procedures.size(); i++) {
                    Procedure p = procedures.get(i);
                    if (p.name.equals(procedureName)) {
                        procedure = i;
                    }
                }
                assertTrue(procedure >= 0, "Unknown procedure: " + procedureName);
            }
            int a = 0;
            for (int i : this.args) {
                a = args[i] ? a * 2 + 1 : a * 2;
            }
            return dfs(procedure, a);
        }
    }

    class BlockStatement extends Statement {
        List<Statement> statements;

        public BlockStatement(List<Statement> statements) {
            this.statements = statements;
        }

        public boolean execute(boolean[] args) {
            for (Statement statement : statements) {
                if (statement.execute(args)) {
                    return true;
                }
            }
            return false;
        }
    }

    public static void main(String[] args) {
        new Thread(new recursion_pm()).start();
    }

    public void run() {
        try {
            in = new BufferedInputStream(new FileInputStream("recursion.in"));
            out = new PrintWriter("recursion.out");
            solve();
            out.close();
        } catch (Exception e) {
            e.printStackTrace();
            System.exit(1);
        }
    }

}
