import java.util.*;
import java.io.*;

public class convex_as_numeric2_jarvis implements Runnable {
    final static double EPS = 1e-9;

    class Line {
        double a;
        double b;
        double c;
        double v;

        Line(int x1, int y1, int x2, int y2, double v) {
            a = y1 - y2;
            b = x2 - x1;
            c = a * x1 + b * y1;
            this.v = v;
            double d = Math.sqrt(a * a + b * b);
            a /= d;
            b /= d;
            c /= d;
        }

        MovingPoint intersect(Line l) {
            double d = a * l.b - b * l.a;
            if (Math.abs(d) < EPS) {
                return null;
            }
            MovingPoint p = new MovingPoint();
            p.x0 = (c * l.b - l.c * b) / d;
            p.y0 = (a * l.c - l.a * c) / d;
            p.dx = (v * l.b - l.v * b) / d;
            p.dy = (l.v * a - v * l.a) / d;
            return p;
        }
    }

    class MovingPoint {
        double x0;
        double y0;
        double dx;
        double dy;

        public String toString() {
            return String.format("[(%.6f, %.6f) ->(%.6f, %.6f)]", x0, y0, dx, dy);
        }
    }

    double vp(Point v1, Point v2) {
        return v1.x * v2.y - v1.y * v2.x;
    }

    double sp(Point v1, Point v2) {
        return v1.x * v2.x + v1.y * v2.y;
    }

    class Point {
        double x;
        double y;
        MovingPoint from;

        public Point(double x, double y) {
            this.x = x;
            this.y = y;
        }

        Point subtract(Point p) {
            return new Point(x - p.x, y - p.y);
        }

        public double sqLen() {
            return x * x + y * y;
        }

        public double len() {
            return Math.sqrt(x * x + y * y);
        }

        Point norm() {
            double d = Math.sqrt(x * x + y * y);
            return new Point(x / d, y / d);
        }


        public String toString() {
            return String.format("(%.6f, %.6f)", x, y);
        }
    }

    class Interval {
        double l;
        double r;
        int sign;

        Interval(double l, double r, int sign) {
            this.l = l;
            this.r = r;
            this.sign = sign;
        }

        public String toString() {
            return String.format("(%.6f, %.6f) %d", l, r, sign);
        }
    }

    double intvp(MovingPoint p1, MovingPoint p2, double a, double b) {
        return
                (p1.dx * p2.dy - p2.dx * p1.dy) * (b * b * b - a * a * a) / 3 +
                (p1.x0 * p2.dy + p1.dx * p2.y0 - p2.x0 * p1.dy - p2.dx * p1.y0) * (b * b - a * a) / 2 +
                (p1.x0 * p2.y0 - p2.x0 * p1.y0) * (b - a);
    }

    Interval[] getInterval(MovingPoint p1, MovingPoint p2, MovingPoint p3) {
        double a = (p2.dx - p1.dx) * (p3.dy - p1.dy) - (p2.dy - p1.dy) * (p3.dx - p1.dx);
        double b = (p2.x0 - p1.x0) * (p3.dy - p1.dy) + (p3.y0 - p1.y0) * (p2.dx - p1.dx) -
                (p2.y0 - p1.y0) * (p3.dx - p1.dx) - (p3.x0 - p1.x0) * (p2.dy - p1.dy);
        double c = (p2.x0 - p1.x0) * (p3.y0 - p1.y0) - (p2.y0 - p1.y0) * (p3.x0 - p1.x0);

        if (Math.abs(a) < EPS) {
            if (Math.abs(b) < EPS) {
                return new Interval[]{new Interval(Double.NEGATIVE_INFINITY, Double.POSITIVE_INFINITY, c > EPS ? 1 : c < -EPS ? -1 : 0)};
            }
            double x = -c / b;
            return new Interval[]{
                    new Interval(Double.NEGATIVE_INFINITY, x, b > 0 ? -1 : 1),
                    new Interval(x, Double.POSITIVE_INFINITY, b > 0 ? 1 : -1),
            };
        } else {
            double d = b * b - 4 * a * c;
            if (d < -EPS) {
                return new Interval[]{new Interval(Double.NEGATIVE_INFINITY, Double.POSITIVE_INFINITY, a < 0 ? -1 : 1)};
            } else if (d < EPS) {
                double x = - b / (2 * a);
                return new Interval[]{
                        new Interval(Double.NEGATIVE_INFINITY, x, a < 0 ? -1 : 1),
                        new Interval(x, Double.POSITIVE_INFINITY, a < 0 ? -1 : 1)
                };
            } else {
                double x1 = (- b - Math.sqrt(d)) / (2 * a);
                double x2 = (- b + Math.sqrt(d)) / (2 * a);
                if (x1 > x2) {
                    double tmp = x1; x1 = x2; x2 = tmp;
                }
                return new Interval[]{
                        new Interval(Double.NEGATIVE_INFINITY, x1, a > 0 ? 1 : -1),
                        new Interval(x1, x2, a > 0 ? -1 : 1),
                        new Interval(x2, Double.POSITIVE_INFINITY, a > 0 ? 1 : -1),
                };
            }
        }
    }

    class Event implements Comparable<Event>{
        double value;
        int sign;
        boolean start;

        public int compareTo(Event e) {
            if (value < e.value - EPS) {
                return -1;
            } else if (value > e.value + EPS) {
                return 1;
            } else {
                return 0;
            }
        }

        Event(double value, int sign, boolean start) {
            this.value = value;
            this.sign = sign;
            this.start = start;
        }
    }

    public void solve() throws IOException {
        Scanner in = new Scanner(new File("convex.in"));
        PrintWriter out = new PrintWriter("convex.out");

        int ln = in.nextInt();
        Line[] l = new Line[ln];
        for (int i = 0; i < ln; i++) {
            int xa = in.nextInt();
            int ya = in.nextInt();
            int xb = in.nextInt();
            int yb = in.nextInt();
            double v = -in.nextDouble();
            l[i] = new Line(xa, ya, xb, yb, v);
        }
        double T = in.nextDouble();

        ArrayList<MovingPoint> mp = new ArrayList<MovingPoint>();
        for (int i = 0; i < ln; i++) {
            for (int j = i + 1; j < ln; j++) {
                MovingPoint mpt = l[i].intersect(l[j]);
                if (mpt != null) {
                    mp.add(mpt);
                }
            }
        }

        double dt = 0.0001;
        double ans = 0;
        for (double t = 0; t < T; t += dt) {
            Point[] p = new Point[mp.size()];
            int n = 0;
            for (MovingPoint q : mp) {
                p[n] = new Point(q.x0 + q.dx * t, q.y0 + q.dy * t);
                p[n].from = q;
                n++;
            }

            Point o = p[0];
            for (int i = 1; i < n; i++) {
                if (o.y > p[i].y || (o.y == p[i].y && o.x > p[i].x)) {
                    o = p[i];
                }
            }

            Point[] st = new Point[n + 1];
            st[0] = o;
            int top = 1;

            Point last = new Point(1, 0);

            while (top == 1 || st[top - 1].subtract(o).len() > EPS) {
                Point best = null;
                double bp = -2;
                for (int j = 0; j < n; j++) {
                    Point dp = p[j].subtract(st[top - 1]);
                    if (dp.len() < EPS) {
                        continue;
                    }
                    dp = dp.norm();

                    double sp = sp(last, dp);
                    if (sp > bp) {
                        bp = sp;
                        best = p[j];
                    }
                }
                if (best == null) {
                    break;
                }
                st[top] = best;
                last = st[top].subtract(st[top - 1]).norm();
                top++;
            }
            top--;

            for (int i = 0; i < top; i++) {
                ans += intvp(st[i].from, st[i + 1].from, t, t + dt) / 2;
 //                System.out.println(st[i]);
            }

//            System.out.println(ans);
        }

        out.printf("%.10f\n", ans / T);

        in.close();
        out.close();
    }

    public void run() {
        try {
            solve();
        } catch (IOException e) {
        }
    }

    public static void main(String[] arg) {
        Locale.setDefault(Locale.US);
        new Thread(new convex_as_numeric2_jarvis()).start();
    }
}