import java.util.*;
import java.io.*;

public class wheels_as implements Runnable {

    PrintWriter out;

    class Vertex {
        int i;
        int original;

        Vertex(int i, int original) {
            this.i = i;
            this.original = original;
        }
    }

    class Edge {
        int i;
        Vertex s;
        Vertex t;
        boolean removed;

        Edge(int i, Vertex s, Vertex t) {
            this.i = i;
            this.s = s;
            this.t = t;
        }
    }

    class Decomposition {
        boolean isVertex;

        Vertex v;
        ArrayList<Decomposition> children;
        ArrayList<Edge> edges;

        public void print(int level) {
            for (int i = 0; i < 2 * level; i++) {
                out.print(" ");
            }
            if (isVertex) {
                out.println("vertex " + v.original);
            } else {
                out.println("wheel " + children.size());
                for (int i = 0; i < children.size(); i++) {
                    children.get(i).print(level + 1);
                    for (int j = 0; j < 2 * level + 2; j++) {
                        out.print(" ");
                    }
                    out.println("edge " + edges.get(i).i);
                }
            }
        }
    }


    class Graph {
        int n;
        ArrayList<Edge>[] edges;
        ArrayList<Edge>[] redges;
        Vertex[] v;
        boolean[] u;
        int[] l;
        int ln;
        int[] c;

        Graph(int n) {
            this.n = n;
            edges = new ArrayList[n];
            redges = new ArrayList[n];
            for (int i = 0; i < n; i++) {
                edges[i] = new ArrayList<Edge>();
                redges[i] = new ArrayList<Edge>();
            }
            v = new Vertex[n];
        }

        void dfs(int i) {
            u[i] = true;
            for (Edge e : edges[i]) {
                if (!e.removed && !u[e.t.i]) {
                    dfs(e.t.i);
                }
            }
            l[ln++] = i;
        }

        void dfs2(int i, int cc) {
            u[i] = true;
            c[i] = cc;
            for (Edge e : redges[i]) {
                if (!e.removed && !u[e.s.i]) {
                    dfs2(e.s.i, cc);
                }
            }
        }

        Decomposition decompose() {
            int min = n + 1;
            int[] bestc = null;
            Edge best = null;
            for (ArrayList<Edge> es : edges) {
                for (Edge e : es) {
                    e.removed = true;

                    u = new boolean[n];
                    l = new int[n];
                    ln = 0;
                    for (int i = 0; i < n; i++) {
                        if (!u[i]) {
                            dfs(i);
                        }
                    }
                    Arrays.fill(u, false);
                    c = new int[n];
                    int cn = 0;
                    for (int i = n - 1; i >= 0; i--) {
                        if (!u[l[i]]) {
                            dfs2(l[i], cn);
                            cn++;
                        }
                    }
                    if (cn < min) {
                        min = cn;
                        bestc = c.clone();
                        best = e;
                    }

                    e.removed = false;
                }
            }

            if (best == null) {
                Decomposition res = new Decomposition();
                res.isVertex = true;
                res.v = v[0];
                return res;
            }

            ArrayList<Integer>[] ans = new ArrayList[min];
            Edge[] via = new Edge[min];
            for (int i = 0; i < min; i++) {
                ans[i] = new ArrayList<Integer>();
            }
            for (int i = 0; i < min; i++) {
                for (int j = 0; j < n; j++) {
                    if (bestc[j] == i) {
                        ans[i].add(j);
                    }
                }
            }

            int[] next = new int[min];
            Arrays.fill(next, -1);
            for (ArrayList<Edge> es : edges) {
                for (Edge e : es) {
                    if (bestc[e.s.i] != bestc[e.t.i]) {
                        assert next[bestc[e.s.i]] == -1;
                        next[bestc[e.s.i]] = bestc[e.t.i];
                        via[bestc[e.s.i]] = e;
                    }
                }
            }
            if (min == 1) {
                via[0] = best;
            }


            Graph[] g = new Graph[min];
            Vertex[] nv = new Vertex[n];
            int[] vn = new int[min];
            for (int i = 0; i < min; i++) {
                g[i] = new Graph(ans[i].size());
                for (int j = 0; j < n; j++) {
                    if (bestc[j] == i) {
                        g[i].v[vn[i]] = new Vertex(vn[i], v[j].original);
                        nv[j] = g[i].v[vn[i]];
                        vn[i]++;
                    }
                }
            }

            for (int i = 0; i < n; i++) {
                for (Edge e : edges[i]) {
                    if (e != via[bestc[i]]) {
                        Edge ne = new Edge(e.i, nv[e.s.i], nv[e.t.i]);
                        g[bestc[i]].edges[nv[e.s.i].i].add(ne);
                        g[bestc[i]].redges[nv[e.t.i].i].add(ne);
                    }
                }
            }

            Decomposition d = new Decomposition();
            d.isVertex = false;
            d.children = new ArrayList<Decomposition>();
            d.edges = new ArrayList<Edge>();

            int j = 0;
            for (int i = 0; i < min; i++) {
                d.children.add(g[i].decompose());
                d.edges.add(via[i]);
                j = next[j];
            }

            return d;
        }
    }

    public void solve() throws IOException {
        Scanner in = new Scanner(new File("wheels.in"));
        out = new PrintWriter("wheels.out");

        int n = in.nextInt();
        int m = in.nextInt();

        assert n <= 200;
        assert m <= 200;

        Graph g = new Graph(n);
        for (int i = 0; i < n; i++) {
            g.v[i] = new Vertex(i, i + 1);
        }
        for (int i = 0; i < m; i++) {
            int s = in.nextInt() - 1;
            int t = in.nextInt() - 1;
            Edge e = new Edge(i + 1, g.v[s], g.v[t]);
            g.edges[s].add(e);
            g.redges[t].add(e);
        }

        Decomposition d = g.decompose();
        d.print(0);

        in.close();
        out.close();
    }

    public void run() {
        try {
            solve();
        } catch (IOException e) {
        }
    }

    public static void main(String[] arg) {
        new Thread(new wheels_as()).start();
    }
}