//  "  "
// ??- -  2007-2008,  
//  :  , tsarev@rain.ifmo.ru
//  :  , poromov@rain.ifmo.ru

import java.io.*;
import java.util.*;

public class polyseg_sp implements Runnable {

	public static void main(String[] args) {
		new Thread(new polyseg_sp()).run();
	}

	public void run() {
		try {
			Locale.setDefault(Locale.US);
			br = new BufferedReader(new FileReader(FILENAME + ".in"));
			out = new PrintWriter(FILENAME + ".out");
			solve();
			out.close();
		} catch (IOException e) {
			e.printStackTrace();
		}
	}

	BufferedReader br;

	PrintWriter out;

	StringTokenizer st;

	String nextToken() {
		while (st == null || !st.hasMoreTokens()) {
			try {
				st = new StringTokenizer(br.readLine());
			} catch (IOException e) {
				e.printStackTrace();
			}
		}
		return st.nextToken();
	}

	int nextInt() {
		return Integer.parseInt(nextToken());
	}

	void myAssert(boolean e, String s) {
		if (!e) {
			throw new Error("Assertion failure " + s);
		}
	}

	private static final String FILENAME = "polyseg";
	Random random = new Random(this.hashCode());
	double eps = 1e-5;
	
	class Segment {
		double x1, y1, x2, y2;
		double a, b, c;
		
		Segment(double x1, double y1, double x2, double y2) {
			this.x1 = x1;
			this.y1 = y1;
			this.x2 = x2;
			this.y2 = y2;
			a = y2 - y1;
			b = x1 - x2;
			c = -a * x1 - b * y1;
			double t = Math.sqrt(a * a + b * b);
			if (a < -eps || (Math.abs(a) < eps && b < -eps)) {
				t = -t;
			}
			a /= t;
			b /= t;
			c /= t;
		}
		
		boolean equals(Segment o) {
			return Math.abs(a - o.a) < eps && Math.abs(b - o.b) < eps && Math.abs(c - o.c) < eps;  
		}
		
		boolean Contains(Point p) {
			if (Math.abs(a * p.x + b * p.y + c) > eps) {
				return false;
			}
			double dx1 = p.x - x1;
			double dy1 = p.x - y1;
			double dx2 = p.x - x2;
			double dy2 = p.x - y2;
			return dx1 * dx2 + dy1 * dy2 < eps;
		}
		
		Point intersect(Segment o) {
			if (Math.abs(a - o.a) < eps && Math.abs(b - o.b) < eps) {
				return null;
			}
			double t1 = x1 * o.a + y1 * o.b + o.c;
			double t2 = x2 * o.a + y2 * o.b + o.c;
			double tt1 = o.x1 * a + o.y1 * b + c;
			double tt2 = o.x2 * a + o.y2 * b + c;
			if (t1 * t2 < eps && tt1 * tt2 < eps) {
				return new Point((b * o.c - o.b * c) / (a * o.b - o.a * b), (a * o.c - o.a * c) / (b * o.a - o.b * a));
			}
			return null;
		}
	}
	
	class Point implements Comparable<Point>{
		double x, y;
		
		Point(double x, double y) {
			this.x = x;
			this.y = y;
		}

		@Override
		public int compareTo(Point o) {
			if (x < o.x - eps) {
				return -1;
			}
			if (x > o.x + eps) {
				return 1;
			}
			if (y < o.y - eps) {
				return -1;
			}
			if (y > o.y + eps) {
				return 1;
			}
			return 0;
		}
	}
	
	class Polygon {
		double[] x, y;
		int n;
		
		Polygon(int n) {
			this.n = n;
			x = new double[n];
			y = new double[n];
			for (int i = 0; i < n; i++) {
				x[i] = nextInt();
				y[i] = nextInt();
				myAssert(Math.abs(x[i]) <= 1e5, "Wrong coordinates");
				myAssert(Math.abs(y[i]) <= 1e5, "Wrong coordinates");
			}
		}

		boolean inside(Point p) {
			for (int i = 0; i < n; i++) {
				Segment ss = new Segment(x[i], y[i], x[(i + 1) % n], y[(i + 1) % n]);
				if (ss.Contains(p)) {
					return true;
				}
			}
			double angle = random.nextDouble() * 2 * Math.PI;
			double a = Math.sin(angle);
			double b = -Math.cos(angle);
			//double c = -a * p.x - b * p.y;
			Segment s = new Segment(p.x, p.y, p.x - b * 1e7, p.y + a * 1e7);
			int count = 0;
			for (int i = 0; i < n; i++) {
				Segment ss = new Segment(x[i], y[i], x[(i + 1) % n], y[(i + 1) % n]);
				if (ss.intersect(s) != null) {
					count++;
				}
			}
			return count % 2 == 1;
		}
	}
	
	public void solve() throws IOException {
		int n = nextInt();
		myAssert(n >= 3 && n <= 1000, "n not in bounds");
		Polygon p = new Polygon(n);
		Segment s = new Segment(nextInt(), nextInt(), nextInt(), nextInt());
		myAssert(Math.abs(s.x1) <= 1e5 + eps, "Wrong coordinates");
		myAssert(Math.abs(s.y1) <= 1e5 + eps, "Wrong coordinates");
		myAssert(Math.abs(s.x2) <= 1e5 + eps, "Wrong coordinates");
		myAssert(Math.abs(s.y2) <= 1e5 + eps, "Wrong coordinates");
		ArrayList<Point> ap = new ArrayList<Point>();
		for (int i = 0; i < n; i++) {
			Segment ss = new Segment(p.x[i], p.y[i], p.x[(i + 1) % n], p.y[(i + 1) % n]);
			if (s.equals(ss)) continue;
			Point pp = s.intersect(ss);
			if (pp != null) {
				ap.add(pp);
			}
		}
		ap.add(new Point(s.x1, s.y1));
		ap.add(new Point(s.x2, s.y2));
		Collections.sort(ap);
		double ans = 0;
		for (int i = 0; i < ap.size() - 1; i++) {
			Point pp = new Point((ap.get(i).x + ap.get(i + 1).x) / 2, (ap.get(i).y + ap.get(i + 1).y) / 2);
			if (p.inside(pp)) {
				double l = (ap.get(i).x - ap.get(i + 1).x) * (ap.get(i).x - ap.get(i + 1).x) + (ap.get(i).y - ap.get(i + 1).y) * (ap.get(i).y - ap.get(i + 1).y);
				ans += Math.sqrt(l);
			}
		}
		out.println(ans);
	}
}
