import java.io.*;
import java.util.*;

//Problem "Square root of a permutation".
//14th Personal Internet Olympiad, season 2007-2008.
//Problem Author: Maxim Buzdalov, buzdalov@rain.ifmo.ru
//Solution Author: Maxim Buzdalov, buzdalov@rain.ifmo.ru

//Uses 64-bit integer instead of BigInteger, so overflows.

public class sqroot_mb_i64 {
    public static void main(String[] args) throws IOException {
         Scanner in = new Scanner(new File("sqroot.in"));
         int n = in.nextInt();
         assert 1 <= n && n <= 100 : "N is out of bounds";
         
         int[] perm = new int[n];
         boolean[] uu = new boolean[n];
         for (int i = 0; i < n; ++i) {
             perm[i] = in.nextInt() - 1;
             assert 0 <= perm[i] && perm[i] < n : "Illegal permutation member (out of bounds)";
             assert !uu[perm[i]] : "Illegal permutation member (duplicate)";
             uu[perm[i]] = true;
         }
         int[] cycleCount = new int[n + 1];
         boolean[] used = new boolean[n];
         for (int i = 0; i < n; ++i) {
             if (!used[i]) {
                 int cl = 0;
                 int j = i;
                 do {
                     ++cl;
                     used[j] = true;
                     j = perm[j];
                 } while (!used[j]);
                 cycleCount[cl]++;
             }
         }

         long[] fact = new long[n + 1];
         long[] divFact = new long[n + 1];
         divFact[0] = 1;
         fact[0] = 1;
         for (int i = 1; i <= n; ++i) {
             divFact[i] = divFact[i - 1] * (i % 2 == 0 ? 1 : i);
             fact[i] = fact[i - 1] * i;
         }

         long[][] C = new long[n + 1][];
         for (int i = 0; i <= n; ++i) {
             C[i] = new long[i + 1];
             C[i][0] = C[i][i] = 1;
             for (int j = 1; j < i; ++j) {
                 C[i][j] = C[i - 1][j] + C[i - 1][j - 1];
             }
         }

         long answer = 1;
         for (int i = 1; answer > 0 && i <= n; ++i) {
             if (cycleCount[i] > 0) {
                 if (i % 2 == 0) {
                     if (cycleCount[i] % 2 == 0) {
                         answer = answer * divFact[cycleCount[i]] * (long)(Math.pow(i, cycleCount[i] / 2));
                     } else {
                         answer = 0;
                     }
                 } else {
                     long mul = 1;
                     for (int j = 2; j <= cycleCount[i]; j += 2) {
                         mul = mul + divFact[j] * (long)Math.pow(i, j / 2) * C[cycleCount[i]][j];
                     }
                     answer = answer * mul;
                 }
             }
         }

         PrintWriter out = new PrintWriter("sqroot.out");
         out.println(answer);
         out.close();
    }
}
