import java.io.*;
import java.util.*;

//Problem "Triangular Agronomy"
//11th Internet Olympiad, advanced level, season 2007-2008
//Problem Author: Maxim Buzdalov, buzdalov@rain.ifmo.ru
//Solution Author: Maxim Buzdalov, buzdalov@rain.ifmo.ru

//Correct solution using sweep line to build DCEL.

public class agronomy_mb implements Runnable {
    static class Point implements Comparable<Point> {
        int x, y;
        
        Point(int x, int y) {
            this.x = x;
            this.y = y;
        }
        
        Point sub(Point arg) {
            return new Point(x - arg.x, y - arg.y);
        }
        
        int vmul(Point arg) {
            return x * arg.y - y * arg.x;
        }
        
        int smul(Point arg) {
            return x * arg.x + y * arg.y;
        }
        
        public int compareTo(Point that) {
            return x == that.x ? y - that.y : x - that.x;
        }
        
        public String toString() {
            return "(" + x + "; " + y + ")";
        }
    }
    
    static class Vertex implements Comparable<Vertex> {
        Point point;
        int incidentEdge;
        int index;
        Vertex(Point point, int index, int edge) {
            this.point = point;
            this.index = index;
            incidentEdge = edge;
        }
        Vertex(Point point, int index) {
            this(point, index, -1);
        }
        public int compareTo(Vertex vertex) {
            return point.compareTo(vertex.point);
        }
    }
    
    static class Edge {
        int startVertex;
        int nextEdge;
        int prevEdge;
        int twinEdge;
        int nextCoincidentEdge;
        int index;
        Edge(int index) {
            this.index = index;
            startVertex = -1;
            nextEdge = -1;
            prevEdge = -1;
            twinEdge = -1;
            nextCoincidentEdge = -1;
        }
    }
    
    static int signum(int value) {
        return value == 0 ? 0 : value > 0 ? 1 : -1;
    }
    
    static int signum(long value) {
        return value == 0 ? 0 : value > 0 ? 1 : -1;
    }
    
    static boolean intersect(Point s0, Point f0, Point s1, Point f1) {
        if (Math.max(s0.x, f0.x) < Math.min(s1.x, f1.x) || Math.max(s0.y, f0.y) < Math.min(s1.y, f1.y) ||
            Math.max(s1.x, f1.x) < Math.min(s0.x, f0.x) || Math.max(s1.y, f1.y) < Math.min(s0.y, f0.y)) {
            return false;
        }
        int vmul00s = signum(s1.sub(s0).vmul(f0.sub(s0)));
        int vmul01s = signum(f0.sub(s0).vmul(f1.sub(s0)));
        int vmul10s = signum(s0.sub(s1).vmul(f1.sub(s1)));
        int vmul11s = signum(f1.sub(s1).vmul(f0.sub(s1)));
        
        return vmul00s * vmul01s > 0 && vmul10s * vmul11s > 0;
    }
    
    static Vertex[] vs;
    static Edge[] es;
    
    static class SweepLineComparator implements Comparator<Edge> {
        int currX;
        
        public int compare(Edge a, Edge b) {
            Point aS = vs[a.startVertex].point;
            Point aF = vs[es[a.twinEdge].startVertex].point;
            Point bS = vs[b.startVertex].point;
            Point bF = vs[es[b.twinEdge].startVertex].point;
            
            assert aS.x <= currX && aS.compareTo(aF) < 0 && aF.x >= currX : "Wrong edge A (" + aS + "--" + aF + ")";
            assert bS.x <= currX && bS.compareTo(bF) < 0 && bF.x >= currX : "Wrong edge B (" + bS + "--" + bF + ")";
            assert !intersect(aS, aF, bS, bF) : "Two segments intersect: " + aS + "--" + aF + " and " + bS + "--" + bF;
            
            long denA = aF.x - aS.x;
            long numA = denA == 0 ? aS.y : aS.y * denA + (aF.y - aS.y) * (currX - aS.x);
            long denB = bF.x - bS.x;
            long numB = denB == 0 ? bS.y : bS.y * denB + (bF.y - bS.y) * (currX - bS.x);
            denA = denA == 0 ? 1 : denA;
            denB = denB == 0 ? 1 : denB;
            
            int rv = signum(numA * denB - numB * denA);
            if (rv != 0) {
                return rv;
            } else {
                if (aS == bS) {
                    rv = bF.sub(bS).vmul(aF.sub(aS));
                } else if (aS == bF) {
                    rv = 1;
                } else if (aF == bS) {
                    rv = -1;
                } else if (aF == bF) {
                    rv = aF.sub(aS).vmul(bF.sub(bS));
                } else {
                    rv = 0;
                }
                assert (rv != 0 || a == b) : "Comparator fault, probably collinear edges";
                return rv;
            }
        }
    }
    
    int firstInt(String s) {
        return Integer.parseInt(s.substring(0, s.indexOf(' ')));
    }
    
    int secondInt(String s) {
        return Integer.parseInt(s.substring(1 + s.indexOf(' ')));
    }
    
    public void run() {
        try {
            BufferedReader in = new BufferedReader(new FileReader("agronomy.in"));
            String first = in.readLine();
            int n = firstInt(first), m = secondInt(first);
            
            assert 3 <= n && n <= 10000 : "N is out of bounds";
            assert 3 <= m && m <= 50000 : "M is out of bounds";

            vs = new Vertex[n];
            es = new Edge[2 * m];            
            int[] reindex = new int[n];
            
            for (int i = 0; i < n; ++i) {
                String pt = in.readLine();
                vs[i] = new Vertex(new Point(firstInt(pt), secondInt(pt)), i);
                assert Math.abs(vs[i].point.x) <= 10000 : "Illegal X";
                assert Math.abs(vs[i].point.y) <= 10000 : "Illegal Y";
            }

            Arrays.sort(vs);            
//            for (Vertex v : vs) {
//                System.err.println(v.point);
//            }
            for (int i = 0; i < n; ++i) {
                reindex[vs[i].index] = i;
            }
            for (int i = 0; i < m; ++i) {
                String eg = in.readLine();
                int start = firstInt(eg), finish = secondInt(eg);
                Edge s = es[2 * i + 0] = new Edge(2 * i + 0);
                Edge f = es[2 * i + 1] = new Edge(2 * i + 1);
                s.startVertex = reindex[start - 1];
                f.startVertex = reindex[finish - 1];
                s.twinEdge = 2 * i + 1;
                f.twinEdge = 2 * i + 0;
                s.nextCoincidentEdge = vs[s.startVertex].incidentEdge;
                f.nextCoincidentEdge = vs[f.startVertex].incidentEdge;
                vs[s.startVertex].incidentEdge = 2 * i + 0;
                vs[f.startVertex].incidentEdge = 2 * i + 1;
            }
            in.close();
            
            SweepLineComparator cmp = new SweepLineComparator();
            TreeSet<Edge> edges = new TreeSet<Edge>(cmp);
            for (int eventIdx = 0; eventIdx < n; ++eventIdx) {
                Vertex event = vs[eventIdx];
                cmp.currX = event.point.x;
                
                ArrayList<Edge> oldEdges = new ArrayList<Edge>();
                ArrayList<Edge> newEdges = new ArrayList<Edge>();
                
                for (int incident = event.incidentEdge; incident != -1; incident = es[incident].nextCoincidentEdge) {
                    Edge e = es[incident];
                    Vertex sv = vs[e.startVertex];
                    Vertex fv = vs[es[e.twinEdge].startVertex];
                    
                    if (sv.compareTo(fv) > 0) {
                        assert edges.contains(es[e.twinEdge]);
                        edges.remove(es[e.twinEdge]);
                        oldEdges.add(es[e.twinEdge]);
                    } else {
                        assert !edges.contains(e);
                        edges.add(e);
                        newEdges.add(e);
                    }
                }
                
                assert (!oldEdges.isEmpty() || !newEdges.isEmpty()) : "An isolated point exists";

                Collections.sort(oldEdges, cmp);
                Collections.sort(newEdges, cmp);

                for (int i = 1; i < oldEdges.size(); ++i) {
                    Edge curr = oldEdges.get(i - 1);
                    Edge next = oldEdges.get(i);
                    curr.nextEdge = next.twinEdge;
                    es[next.twinEdge].prevEdge = curr.index;
                }                
                for (int i = 1; i < newEdges.size(); ++i) {
                    Edge curr = newEdges.get(i - 1);
                    Edge next = newEdges.get(i);
                    curr.prevEdge = next.twinEdge;
                    es[next.twinEdge].nextEdge = curr.index;
                }
                if (oldEdges.isEmpty()) {
                    Edge l = newEdges.get(newEdges.size() - 1);
                    Edge f = newEdges.get(0);
                    l.prevEdge = f.twinEdge;
                    es[f.twinEdge].nextEdge = l.index;
                } else if (newEdges.isEmpty()) {
                    Edge l = oldEdges.get(oldEdges.size() - 1);
                    Edge f = oldEdges.get(0);
                    l.nextEdge = f.twinEdge;
                    es[f.twinEdge].prevEdge = l.index;
                } else {
                    oldEdges.get(oldEdges.size() - 1).nextEdge = newEdges.get(newEdges.size() - 1).index;
                    newEdges.get(newEdges.size() - 1).prevEdge = oldEdges.get(oldEdges.size() - 1).index;
                    es[newEdges.get(0).twinEdge].nextEdge = oldEdges.get(0).twinEdge;
                    es[oldEdges.get(0).twinEdge].prevEdge = newEdges.get(0).twinEdge;
                }
            } 
            
            boolean[] usedEdges = new boolean[2 * m];
            int longCount = 0;
            
            ArrayList<int[]> triangles = new ArrayList<int[]>();
            
//            System.err.println("Vertices: ");
//            for (Vertex v : vs) {
//                System.err.println(v.point + " " + v.incidentEdge);
//            }
//            System.err.println("Edges: ");
//            for (Edge e : es) {
//                System.err.println(e.startVertex + "--> ... prev=" + e.prevEdge + ", next=" + e.nextEdge + ", twin=" + e.twinEdge);
//            }
            
            for (int i = 0; i < 2 * m; ++i) {
                if (!usedEdges[i]) {
                    Edge s = es[i], c = s;
                    
                    int[] tri = new int[3];
                    int idx = 0;
                    
                    int sq2 = 0;
                    do {
                        usedEdges[c.index] = true;
                        Edge tw = es[c.twinEdge];
                        sq2 += vs[c.startVertex].point.vmul(vs[tw.startVertex].point);
                        if (idx <= 2) {
                            tri[idx++] = 1 + c.index / 2;
                        } else if (idx == 3) {
                            longCount++;
                            idx++;
                        }
                        c = es[c.nextEdge];
                    } while (c != s);
                    assert idx >= 3 : "A short contour";
                    if (idx == 3 && sq2 > 0) {
                        triangles.add(tri);
                    }
                    assert longCount <= 1 : "Non-triangle contour exists";
                }
            }
            
            PrintWriter out = new PrintWriter("agronomy.out");
            out.println(triangles.size());
            for (int[] t : triangles) {
                out.println(t[0] + " " + t[1] + " " + t[2]);
            }
            out.close();
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
    }
    
    public static void main(String[] args) {
        new agronomy_mb().run();
    }
}
