import java.io.*;
import java.util.*;

//Visibility graph optimized, bitsets. O(N^2 log N + N^3 / 32)

public class interfering_mb {
    static class Point {
        int x, y;
        Point(StringTokenizer st) {
            this(Integer.parseInt(st.nextToken()), Integer.parseInt(st.nextToken()));
            assert Math.abs(x) <= 10000 && Math.abs(y) <= 10000 : "Coordinates out of bounds";
        }
        Point(int x, int y) {
            this.x = x;
            this.y = y;
        }
        Point sub(Point arg) {
            return new Point(x - arg.x, y - arg.y);
        }
        Point add(Point arg) {
            return new Point(x + arg.x, y + arg.y);
        }
        int vmul(Point arg) {
            return x * arg.y - y * arg.x;
        }
        int norm() {
            return x * x + y * y;
        }
        public String toString() {
            return "(" + x + "; " + y + ")";
        }
        public boolean equals(Object o) {
            Point p = (Point)o;
            return x == p.x && y == p.y;
        }
    }
    
    static class IndexedPoint extends Point {
        int index;
        IndexedPoint(Point p, int i) {
            super(p.x, p.y);
            index = i;
        }
        public String toString() {
            return super.toString() + "@" + index;
        }
    }
    
    static int signum(int a) {
        return a > 0 ? 1 : a == 0 ? 0 : -1;
    }
    
    static boolean isInside(Point a, Point b, Point c, Point p) {
        a = a.sub(p);
        b = b.sub(p);
        c = c.sub(p);
        return 
            a.vmul(b) > 0 && b.vmul(c) > 0 && c.vmul(a) > 0 ||
            a.vmul(b) < 0 && b.vmul(c) < 0 && c.vmul(a) < 0;
    }
    
    static boolean intersect(Point s1, Point f1, Point s2, Point f2) {
        return 
            !(
                Math.max(s1.x, f1.x) < Math.min(s2.x, f2.x) || Math.max(s2.x, f2.x) < Math.min(s1.x, f1.x) ||
                Math.max(s1.y, f1.y) < Math.min(s2.y, f2.y) || Math.max(s2.y, f2.y) < Math.min(s1.y, f1.y)
            )
             &&
            (s2.sub(s1).vmul(f1.sub(s1)) >= 0 && f1.sub(s1).vmul(f2.sub(s1)) >= 0 || s2.sub(s1).vmul(f1.sub(s1)) <= 0 && f1.sub(s1).vmul(f2.sub(s1)) <= 0)
             &&
            (s1.sub(s2).vmul(f2.sub(s2)) >= 0 && f2.sub(s2).vmul(f1.sub(s2)) >= 0 || s1.sub(s2).vmul(f2.sub(s2)) <= 0 && f2.sub(s2).vmul(f1.sub(s2)) <= 0);
    }

    static class Segment {
        Point start, finish;
        Segment(Point s, Point f) {
            start = s;
            finish = f;
        }
        public String toString() {
            return start + "--" + finish;
        }
        public boolean equals(Object o) {
            Segment s = (Segment)o;
            return start.equals(s.start) && finish.equals(s.finish) || start.equals(s.finish) && finish.equals(s.start);
        }
    }

    
    public static void main(String[] args) throws IOException {
        /**** Reading ****/
        BufferedReader in = new BufferedReader(new FileReader("interfering.in"));
        int n = Integer.parseInt(in.readLine());
        final Point[] polySrc = new Point[n];
        for (int i = 0; i < n; ++i) {
            polySrc[i] = new Point(new StringTokenizer(in.readLine()));
        }
        StringTokenizer st = new StringTokenizer(in.readLine());
        Point start = new Point(st);
        Point finish = new Point(st);
        in.close();
        
        /**** Preparations ****/
        int square = 0;
        
        for (int i = 0; i < n; ++i) {
            square += polySrc[i].vmul(polySrc[(i + 1) % n]);
        }
        
        if (square < 0) {
            for (int i = 0, j = n - 1; i < j; ++i, --j) {
                Point t = polySrc[i];
                polySrc[i] = polySrc[j];
                polySrc[j] = t;
            }
        }
        
        BitSet[] graph = new BitSet[n];
        for (int i = 0; i < n; ++i) {
            graph[i] = new BitSet(n);
        }

        int[] prev = new int[n];
        int[] next = new int[n];
        for (int i = 0; i < n; ++i) {
            next[i] = (i + 1) % n;
            prev[i] = (i - 1 + n) % n;
        }        
        
        /**** Visibility orgraph building ****/
        
        class SegmentComparator implements Comparator<Segment> {
            Point dir;
    
            public SegmentComparator() {
                this.dir = new Point(10001, 0);
            }
            
            public void setDirection(Point dir) {        
                this.dir = dir;
            }
            
            public int compare(Segment a, Segment b) {
                Point diffA = a.finish.sub(a.start);
                Point diffB = b.finish.sub(b.start);
                int numLeft = a.start.vmul(diffA);
                int denLeft = dir.vmul(diffA);
                int numRight = b.start.vmul(diffB);
                int denRight = dir.vmul(diffB);
                long left = (long)numLeft * denRight;
                long right = (long)numRight * denLeft;
                long denden = (long)denRight * denLeft;
                if (denden < 0) {
                    left = -left;
                    right = -right;
                }
                if (left < right) {
                    return -1;
                } else if (left > right) {
                    return 1;
                } else {
                    boolean aStartOn = a.start.vmul(dir) == 0;
                    boolean bStartOn = b.start.vmul(dir) == 0;
                    Point aOnLine  = aStartOn ? a.start : a.finish;
                    Point aOffLine = aStartOn ? a.finish : a.start;
                    Point bOnLine  = bStartOn ? b.start : b.finish;
                    Point bOffLine = bStartOn ? b.finish : b.start;
                    
                    int vmulA = signum(aOnLine.vmul(aOffLine));
                    int vmulB = signum(bOnLine.vmul(bOffLine));
                    int vmulAB = aOffLine.sub(aOnLine).vmul(bOffLine.sub(bOnLine));
                    if (vmulA == vmulB) {
                        return vmulA * vmulAB;
                    } else {
                        return vmulB;
                    }
                }
            }
        }

        class EventComparator implements Comparator<Point> {
            public int compare(Point a, Point b) {
                boolean aInFirst = a.y > 0 || a.y == 0 && a.x > 0;
                boolean bInFirst = b.y > 0 || b.y == 0 && b.x > 0;
                if (aInFirst != bInFirst) {
                    return aInFirst ? -1 : 1;
                } else {
                    int vmul = a.vmul(b);
                    if (vmul != 0) {
                        return -vmul;
                    } else {
                        return a.norm() - b.norm();
                    }
                }
            }
        }

        final Point zero = new Point(0, 0);

        for (int u = 0; u < n - 1; ++u) {
            final Point base = polySrc[u];
            IndexedPoint[] poly = new IndexedPoint[n];
            
            for (int i = 0; i < n; ++i) {
                poly[i] = new IndexedPoint(polySrc[i].sub(base), i);
            }
            
            final Point prevb = poly[prev[u]];
            final Point nextb = poly[next[u]];
            final Point rightmost = new Point(10001, 0);
            //Initial segment tree building.
            SegmentComparator segmentComparator = new SegmentComparator();
            TreeSet<Segment> segments = new TreeSet<Segment>(segmentComparator);
            for (int i = 0; i < n; ++i) {
                if (i != u && next[i] != u && intersect(zero, rightmost, poly[i], poly[next[i]])) {
                    int vmul = poly[i].vmul(poly[next[i]]);
                    if (vmul == 0) {
                        continue;
                    }
                    if (vmul > 0 && poly[i].y == 0 || vmul < 0 && poly[next[i]].y == 0) {
                        continue;
                    }
                    segments.add(new Segment(poly[i], poly[next[i]]));
                }
            }
            //Events creation
            IndexedPoint[] eventPts = new IndexedPoint[n - 1];
            for (int i = 0, j = 0; i < n; ++i) {
                if (i != u) {
                    eventPts[j++] = poly[i];
                }
            }
            Arrays.sort(eventPts, new EventComparator());
            
            for (int i = 0; i < n - 1; ++i) {
                int cur = eventPts[i].index;
                boolean visibleGuard = (u > cur) || (i > 0 && eventPts[i - 1].vmul(eventPts[i]) == 0);
                boolean visible = false;
                segmentComparator.setDirection(eventPts[i]);
                Segment one = new Segment(poly[cur], poly[next[cur]]);
                Segment two = new Segment(poly[cur], poly[prev[cur]]);
                if (!visibleGuard) {
                    Segment first = segments.size() > 0 ? segments.first() : null;
                    visible |= first != null && (one.equals(first) || two.equals(first));
                }
                int oneOrient = one.start.vmul(one.finish);
                if (oneOrient > 0) {
                    segments.add(one);
                } else if (oneOrient < 0) {
                    segments.remove(one);
                }
                int twoOrient = two.start.vmul(two.finish);
                if (twoOrient > 0) {
                    segments.add(two);
                } else if (twoOrient < 0) {
                    segments.remove(two);
                }
                if (!visibleGuard && !visible) {
                    Segment first = segments.size() > 0 ? segments.first() : null;
                    visible |= first != null && (one.equals(first) || two.equals(first));
                }
                
                if (visible && !visibleGuard) {
                    Point nextc = one.finish.sub(one.start);
                    Point prevc = two.finish.sub(two.start);
                    Point curb = eventPts[i];
                    Point basec = zero.sub(eventPts[i]);
                    
                    int basecnt = (prevb.vmul(nextb) > 0 ? 1 : 0) + (nextb.vmul(curb ) > 0 ? 1 : 0) + ( curb.vmul(prevb) > 0 ? 1 : 0);
                    int curcnt  = (prevc.vmul(nextc) > 0 ? 1 : 0) + (nextc.vmul(basec) > 0 ? 1 : 0) + (basec.vmul(prevc) > 0 ? 1 : 0);
                    if (basecnt >= 2 && curcnt >= 2) {
                        graph[u].set(cur);
                        graph[cur].set(u);
                    }
                }
            }
            graph[u].set(next[u]);
            graph[u].set(prev[u]);            
            graph[next[u]].set(u);
            graph[prev[u]].set(u);
        }
        
        //Setting the orientation.
        for (int i = 0; i < n; ++i) {
            for (int j = i + 1; j < n; ++j) {
                if (graph[i].get(j)) {
                    graph[i].clear(j);
                    graph[j].clear(i);
                        int vmuls = polySrc[j].sub(polySrc[i]).vmul(start.sub(polySrc[i]));
                    int vmulf = polySrc[j].sub(polySrc[i]).vmul(finish.sub(polySrc[i]));
                    if (vmuls > 0 && vmulf > 0) {
                        graph[i].set(j);
                    } else if (vmuls < 0 && vmulf < 0) {
                        graph[j].set(i);
                    }
                }
            }
        }
        
        /**** Finding a triangle in the visibility orgraph ****/
        
        BitSet[] graph2 = new BitSet[n];
        
        for (int i = 0; i < n; ++i) {
            graph2[i] = new BitSet(n);
            for (int j = graph[i].nextSetBit(0); j >= 0; j = graph[i].nextSetBit(j + 1)) {
                graph2[i].or(graph[j]);
            }
        }
        BitSet[] rgraph = new BitSet[n];
        for (int i = 0; i < n; ++i) {
            rgraph[i] = new BitSet(n);
            for (int j = 0; j < n; ++j) {
                if (graph[j].get(i)) {
                    rgraph[i].set(j);
                }
            }
        }
        
        PrintWriter out = new PrintWriter("interfering.out");
        for (int i = 0; i < n; ++i) {
            BitSet test = (BitSet) rgraph[i].clone();
            test.and(graph2[i]);
            if (test.cardinality() > 0) {
                //Yes!!
                int p0 = i;
                int p2 = test.nextSetBit(0);
                BitSet test1 = (BitSet) rgraph[p2].clone();
                test1.and(graph[p0]);
                int p1 = test1.nextSetBit(0);
                if (square > 0) {
                    out.println((p0 + 1) + " " + (p1 + 1) + " " + (p2 + 1));
                } else {
                    out.println((n - p0) + " " + (n - p1) + " " + (n - p2));
                }
                out.close();
                return;
            }
        }
        
        out.println("Impossible");
        out.close();
    }
}
