import java.io.*;
import java.util.*;

//A straightforward solution. O(N^3)

public class interfering_mb_slow1 {
    static class Point {
        int x, y;
        Point(StringTokenizer st) {
            this(Integer.parseInt(st.nextToken()), Integer.parseInt(st.nextToken()));
            assert Math.abs(x) <= 10000 && Math.abs(y) <= 10000 : "Coordinates out of bounds";
        }
        Point(int x, int y) {
            this.x = x;
            this.y = y;
        }
        Point sub(Point arg) {
            return new Point(x - arg.x, y - arg.y);
        }
        int vmul(Point arg) {
            return x * arg.y - y * arg.x;
        }
        public String toString() {
            return "(" + x + "; " + y + ")";
        }
    }
    
    static boolean isInside(Point a, Point b, Point c, Point p) {
        a = a.sub(p);
        b = b.sub(p);
        c = c.sub(p);
        return 
            a.vmul(b) > 0 && b.vmul(c) > 0 && c.vmul(a) > 0 ||
            a.vmul(b) < 0 && b.vmul(c) < 0 && c.vmul(a) < 0;
    }
    
    static boolean intersect(Point s1, Point f1, Point s2, Point f2) {
        return 
            !(Math.max(s1.x, f1.x) < Math.min(s2.x, f2.x) || Math.max(s2.x, f2.x) < Math.min(s1.x, f1.x) ||
              Math.max(s1.y, f1.y) < Math.min(s2.y, f2.y) || Math.max(s2.y, f2.y) < Math.min(s1.y, f1.y)
            )
             &&
            (s2.sub(s1).vmul(f1.sub(s1)) >= 0 && f1.sub(s1).vmul(f2.sub(s1)) >= 0 || s2.sub(s1).vmul(f1.sub(s1)) <= 0 && f1.sub(s1).vmul(f2.sub(s1)) <= 0)
             &&
            (s1.sub(s2).vmul(f2.sub(s2)) >= 0 && f2.sub(s2).vmul(f1.sub(s2)) >= 0 || s1.sub(s2).vmul(f2.sub(s2)) <= 0 && f2.sub(s2).vmul(f1.sub(s2)) <= 0);
    }

    public static void main(String[] args) throws IOException {
        BufferedReader in = new BufferedReader(new FileReader("interfering.in"));
        int n = Integer.parseInt(in.readLine());
        assert 3 <= n && n <= 1000 : "N is out of bounds";
        Point[] poly = new Point[n];
        for (int i = 0; i < n; ++i) {
            poly[i] = new Point(new StringTokenizer(in.readLine()));
        }
        StringTokenizer st = new StringTokenizer(in.readLine());
        Point start = new Point(st);
        Point finish = new Point(st);
        in.close();
        
        for (int i = 0; i < n; ++i) {
            int j = (i + 1) % n;
            int k = (j + 1) % n;
            assert poly[j].sub(poly[i]).vmul(poly[k].sub(poly[j])) != 0 : "Three consecutive points lie on the same line";
        }
        
        int square = 0;
        
        for (int i = 0; i < n; ++i) {
            square += poly[i].vmul(poly[(i + 1) % n]);
        }
        
        if (square < 0) {
            for (int i = 0, j = n - 1; i < j; ++i, --j) {
                Point t = poly[i];
                poly[i] = poly[j];
                poly[j] = t;
            }
        }
        
        boolean[][] graph = new boolean[n][n];
        
        long t0 = System.currentTimeMillis();
        
        for (int i = 0; i < n; ++i) {
next:            for (int j = i + 1; j < n; ++j) {
                if (intersect(poly[i], poly[j], start, finish)) {
                    continue next;
                }
                {
                    int im = (i + n - 1) % n;
                    int ip = (i + 1) % n;
                    int jm = (j + n - 1) % n;
                    int jp = (j + 1) % n;
                    Point pim = poly[im].sub(poly[i]);
                    Point pip = poly[ip].sub(poly[i]);
                    Point pjm = poly[jm].sub(poly[j]);
                    Point pjp = poly[jp].sub(poly[j]);
                    Point ij =  poly[j].sub(poly[i]);
                    Point ji =  poly[i].sub(poly[j]);
                    
                    if (!(
                        (pim.vmul(ij) < 0 && ij.vmul(pip) < 0 || ij.vmul(pip) < 0 && pip.vmul(pim) < 0 || pip.vmul(pim) < 0 && pim.vmul(ij) < 0)
                            &&
                        (pjm.vmul(ji) < 0 && ji.vmul(pjp) < 0 || ji.vmul(pjp) < 0 && pjp.vmul(pjm) < 0 || pjp.vmul(pjm) < 0 && pjm.vmul(ji) < 0)
                    )) {
                        continue next;
                    }
                }
                for (int k = 0; k < n; ++k) {
                    int l = (k + 1) % n;
                    if (i != k && j != k && i != l && j != l) {
                        if (intersect(poly[i], poly[j], poly[k], poly[l])) {
                            continue next;
                        }
                    }
                }
                graph[i][j] = graph[j][i] = true;
            }
            int j = (i + 1) % n;
            graph[i][j] = graph[j][i] = true;
        }

        long t1 = System.currentTimeMillis();
        
        System.err.println("Graph building: " + (t1 - t0));

        PrintWriter out = new PrintWriter("interfering.out");
        for (int i = 0; i < n; ++i) {
            for (int j = i + 1; j < n; ++j) {
                for (int k = j + 1; k < n; ++k) {
                    if (graph[i][j] && graph[j][k] && graph[k][i]) {
                        if (isInside(poly[i], poly[j], poly[k], start) && isInside(poly[i], poly[j], poly[k], finish)) {
                            if (square > 0) {
                                out.println((i + 1) + " " + (j + 1) + " " + (k + 1));
                            } else {
                                out.println((n - i) + " " + (n - j) + " " + (n - k));
                            }
                            out.close();
                            System.err.println("Triangle finding: " + (System.currentTimeMillis() - t1));
                            return;
                        }
                    }
                }
            }
        }
        out.println("Impossible");
        out.close();
        System.err.println("Triangle finding: " + (System.currentTimeMillis() - t1));
    }
}
