import java.io.*;
import java.util.*;

//Visibility graph optimized. O(N^2 log N + N^3 / 6)

//1. The condition under which some edge started to be tested against geometry is wrong.

public class interfering_mb_wrong4 {
    static class Point {
	int x, y;
	Point(StringTokenizer st) {
	    this(Integer.parseInt(st.nextToken()), Integer.parseInt(st.nextToken()));
	    assert Math.abs(x) <= 10000 && Math.abs(y) <= 10000 : "Coordinates out of bounds";
	}
	Point(int x, int y) {
	    this.x = x;
	    this.y = y;
	}
	Point sub(Point arg) {
	    return new Point(x - arg.x, y - arg.y);
	}
	int vmul(Point arg) {
	    return x * arg.y - y * arg.x;
	}
	int norm() {
	    return x * x + y * y;
	}
	public String toString() {
	    return "(" + x + "; " + y + ")";
	}
    }
    
    static boolean isInside(Point a, Point b, Point c, Point p) {
	a = a.sub(p);
	b = b.sub(p);
	c = c.sub(p);
	return 
	    a.vmul(b) > 0 && b.vmul(c) > 0 && c.vmul(a) > 0 ||
	    a.vmul(b) < 0 && b.vmul(c) < 0 && c.vmul(a) < 0;
    }
    
    static boolean intersect(Point s1, Point f1, Point s2, Point f2) {
	return 
	    !(
		Math.max(s1.x, f1.x) < Math.min(s2.x, f2.x) || Math.max(s2.x, f2.x) < Math.min(s1.x, f1.x) ||
		Math.max(s1.y, f1.y) < Math.min(s2.y, f2.y) || Math.max(s2.y, f2.y) < Math.min(s1.y, f1.y)
	    )
	     &&
	    (s2.sub(s1).vmul(f1.sub(s1)) >= 0 && f1.sub(s1).vmul(f2.sub(s1)) >= 0 || s2.sub(s1).vmul(f1.sub(s1)) <= 0 && f1.sub(s1).vmul(f2.sub(s1)) <= 0)
	     &&
	    (s1.sub(s2).vmul(f2.sub(s2)) >= 0 && f2.sub(s2).vmul(f1.sub(s2)) >= 0 || s1.sub(s2).vmul(f2.sub(s2)) <= 0 && f2.sub(s2).vmul(f1.sub(s2)) <= 0);
    }

    public static void main(String[] args) throws IOException {
	BufferedReader in = new BufferedReader(new FileReader("interfering.in"));
	int n = Integer.parseInt(in.readLine());
	assert 3 <= n && n <= 1000 : "N is out of bounds";
	final Point[] poly = new Point[n];
	for (int i = 0; i < n; ++i) {
	    poly[i] = new Point(new StringTokenizer(in.readLine()));
	}
	StringTokenizer st = new StringTokenizer(in.readLine());
	Point start = new Point(st);
	Point finish = new Point(st);
	in.close();
	
	for (int i = 0; i < n; ++i) {
	    int j = (i + 1) % n;
	    int k = (j + 1) % n;
	    assert poly[j].sub(poly[i]).vmul(poly[k].sub(poly[j])) != 0 : "Three consecutive points lie on the same line";
	}
	
	int square = 0;
	
	for (int i = 0; i < n; ++i) {
	    square += poly[i].vmul(poly[(i + 1) % n]);
	}
	
	if (square < 0) {
	    for (int i = 0, j = n - 1; i < j; ++i, --j) {
		Point t = poly[i];
		poly[i] = poly[j];
		poly[j] = t;
	    }
	}
	
	boolean[][] graph = new boolean[n][n];

	Integer[] pool = new Integer[n];
	int[] prev = new int[n];
	int[] next = new int[n];
	for (int i = 0; i < n; ++i) {
	    pool[i] = i;
	    next[i] = (i + 1) % n;
	    prev[i] = (i - 1 + n) % n;
	}	
	
	Integer[] events = new Integer[n - 1];
	for (int u = 0; u < n; ++u) {
	    final Point src = poly[u];
	    for (int j = 0, k = 0; j < n; ++j) {
		if (j != u) {
		    events[k++] = pool[j];
		}
	    }
	    class BaseComparator implements Comparator<Integer> {
		final boolean mode;
		BaseComparator(boolean mode) {
		    this.mode = mode;
		}
		public int compare(Integer a, Integer b) {
		    Point pa = poly[a];
		    Point pb = poly[b];
		    boolean aIsInFirst = pa.y > src.y || pa.y == src.y && pa.x > src.x;
		    boolean bIsInFirst = pb.y > src.y || pb.y == src.y && pb.x > src.x;
		    if (aIsInFirst == bIsInFirst) {
			pa = pa.sub(src);
			pb = pb.sub(src);
			int vm = -pa.vmul(pb);
			if (vm != 0) {
			    return vm;
			}
			return (mode ? 1 : -1) * (pa.norm() - pb.norm());
		    } else {
			return aIsInFirst ? -1 : 1;
		    }
		}
	    }
	    BaseComparator srcComparator = new BaseComparator(false);
	    Arrays.sort(events, srcComparator);
	    TreeSet<Integer> eventSet = new TreeSet<Integer>(new BaseComparator(true));
	    for (int i = 0; i < n; ++i) {
		Point s = poly[i].sub(src);
		Point f = poly[next[i]].sub(src);
		if (s.y == f.y) {
		    continue;
		}
		if (s.y >= 0 && 0 >= f.y) {
		    if (s.x * (f.y - s.y) < s.y * (f.x - s.x)) {
			if (f.y < 0) {
			    eventSet.add(pool[i]);
			} else {
			    eventSet.add(pool[next[i]]);
			}
		    }
		} else if (s.y <= 0 && 0 <= f.y) {
		    if (s.x * (f.y - s.y) > s.y * (f.x - s.x)) {
			if (s.y < 0) {
			    eventSet.add(pool[next[i]]);
			} else {
			    eventSet.add(pool[i]);
			}
		    }
		}
	    }
	    for (int i = 0; i < n - 1; ++i) {
		int cur = events[i];
		if (!eventSet.isEmpty() && eventSet.first() == cur) {
		    if (!intersect(start, finish, poly[u], poly[cur])) {
			Point pu = poly[prev[u]].sub(poly[u]);
			Point nu = poly[next[u]].sub(poly[u]);
			Point pc = poly[prev[cur]].sub(poly[cur]);
			Point nc = poly[next[cur]].sub(poly[cur]);
			Point cu = poly[cur].sub(poly[u]);
			Point uc = poly[u].sub(poly[cur]);
			if (
			    (nu.vmul(cu) > 0 && cu.vmul(pu) > 0 || cu.vmul(pu) > 0 && pu.vmul(nu) > 0 || pu.vmul(nu) > 0 && nu.vmul(cu) > 0)
				&&
			    (nc.vmul(uc) > 0 && uc.vmul(pc) > 0 || uc.vmul(pc) > 0 && pc.vmul(nc) > 0 || pc.vmul(nc) > 0 && nc.vmul(uc) > 0)
			) {
			    graph[u][cur] = graph[cur][u] = true;
			}
		    }
		}
		eventSet.remove(cur);
		int prv = prev[cur];
		int nxt = next[cur];
		if (srcComparator.compare(pool[cur], pool[prv]) < 0) {
		    eventSet.add(pool[prv]);
		}
		if (srcComparator.compare(pool[cur], pool[nxt]) < 0) {
		    eventSet.add(pool[nxt]);
		}
	    }
	}
	for (int i = 0; i < n; ++i) {
	    graph[i][next[i]] = graph[next[i]][i] = true;
	}
/* *
	for (int i = 0; i < n; ++i) {
	    for (int j = 0; j < n; ++j) {
		if (square > 0) {
		    System.out.print(graph[i][j] ? "+" : "-");
		} else {
		    System.out.print(graph[n - i - 1][n - j - 1] ? "+" : "-");
		}
	    }
	    System.out.println();
	}
/**/
	PrintWriter out = new PrintWriter("interfering.out");
	for (int i = 0; i < n; ++i) {
	    for (int j = i + 1; j < n; ++j) {
		for (int k = j + 1; k < n; ++k) {
		    if (graph[i][j] && graph[j][k] && graph[k][i]) {
			if (isInside(poly[i], poly[j], poly[k], start) && isInside(poly[i], poly[j], poly[k], finish)) {
			    if (square > 0) {
				out.println((i + 1) + " " + (j + 1) + " " + (k + 1));
			    } else {
				out.println((n - i) + " " + (n - j) + " " + (n - k));
			    }
			    out.close();
			    return;
			}
		    }
		}
	    }
	}
	out.println("Impossible");
	out.close();
    }
}
