import java.io.*;
import java.util.*;

//Visibility graph optimized, bitsets. O(N^2 log N + N^3 / 32)

public class interfering_mb_wrong4_speedup {
    static class Point {
	int x, y;
	Point(StringTokenizer st) {
	    this(Integer.parseInt(st.nextToken()), Integer.parseInt(st.nextToken()));
	    assert Math.abs(x) <= 10000 && Math.abs(y) <= 10000 : "Coordinates out of bounds";
	}
	Point(int x, int y) {
	    this.x = x;
	    this.y = y;
	}
	Point sub(Point arg) {
	    return new Point(x - arg.x, y - arg.y);
	}
	int vmul(Point arg) {
	    return x * arg.y - y * arg.x;
	}
	int norm() {
	    return x * x + y * y;
	}
	public String toString() {
	    return "(" + x + "; " + y + ")";
	}
    }
    
    static int signum(int a) {
	return a > 0 ? 1 : a == 0 ? 0 : -1;
    }
    
    static boolean isInside(Point a, Point b, Point c, Point p) {
	a = a.sub(p);
	b = b.sub(p);
	c = c.sub(p);
	return 
	    a.vmul(b) > 0 && b.vmul(c) > 0 && c.vmul(a) > 0 ||
	    a.vmul(b) < 0 && b.vmul(c) < 0 && c.vmul(a) < 0;
    }
    
    static boolean intersect(Point s1, Point f1, Point s2, Point f2) {
	return 
	    !(
		Math.max(s1.x, f1.x) < Math.min(s2.x, f2.x) || Math.max(s2.x, f2.x) < Math.min(s1.x, f1.x) ||
		Math.max(s1.y, f1.y) < Math.min(s2.y, f2.y) || Math.max(s2.y, f2.y) < Math.min(s1.y, f1.y)
	    )
	     &&
	    (s2.sub(s1).vmul(f1.sub(s1)) >= 0 && f1.sub(s1).vmul(f2.sub(s1)) >= 0 || s2.sub(s1).vmul(f1.sub(s1)) <= 0 && f1.sub(s1).vmul(f2.sub(s1)) <= 0)
	     &&
	    (s1.sub(s2).vmul(f2.sub(s2)) >= 0 && f2.sub(s2).vmul(f1.sub(s2)) >= 0 || s1.sub(s2).vmul(f2.sub(s2)) <= 0 && f2.sub(s2).vmul(f1.sub(s2)) <= 0);
    }

    public static void main(String[] args) throws IOException {
	BufferedReader in = new BufferedReader(new FileReader("interfering.in"));
	int n = Integer.parseInt(in.readLine());
	assert 3 <= n && n <= 1000 : "N is out of bounds";
	final Point[] poly = new Point[n];
	for (int i = 0; i < n; ++i) {
	    poly[i] = new Point(new StringTokenizer(in.readLine()));
	}
	StringTokenizer st = new StringTokenizer(in.readLine());
	Point start = new Point(st);
	Point finish = new Point(st);
	in.close();
	
	for (int i = 0; i < n; ++i) {
	    int j = (i + 1) % n;
	    int k = (j + 1) % n;
	    assert poly[j].sub(poly[i]).vmul(poly[k].sub(poly[j])) != 0 : "Three consecutive points lie on the same line";
	}
	
	int square = 0;
	
	for (int i = 0; i < n; ++i) {
	    square += poly[i].vmul(poly[(i + 1) % n]);
	}
	
	if (square < 0) {
	    for (int i = 0, j = n - 1; i < j; ++i, --j) {
		Point t = poly[i];
		poly[i] = poly[j];
		poly[j] = t;
	    }
	}
	
	BitSet[] graph = new BitSet[n];
	for (int i = 0; i < n; ++i) {
	    graph[i] = new BitSet(n);
	}

	Integer[] pool = new Integer[n];
	int[] prev = new int[n];
	int[] next = new int[n];
	for (int i = 0; i < n; ++i) {
	    pool[i] = i;
	    next[i] = (i + 1) % n;
	    prev[i] = (i - 1 + n) % n;
	}	
	
	long time0 = System.currentTimeMillis();
	
	Integer[] events = new Integer[n - 1];
	for (int u = 0; u < n; ++u) {
	    final Point src = poly[u];
	    for (int j = 0, k = 0; j < n; ++j) {
		if (j != u) {
		    events[k++] = pool[j];
		}
	    }
	    class BaseComparator implements Comparator<Integer> {
		final boolean mode;
		BaseComparator(boolean mode) {
		    this.mode = mode;
		}
		public int compare(Integer a, Integer b) {
		    Point pa = poly[a].sub(src);
		    Point pb = poly[b].sub(src);
		    boolean aIsInFirst = pa.y > 0 || pa.y == 0 && pa.x > 0;
		    boolean bIsInFirst = pb.y > 0 || pb.y == 0 && pb.x > 0;
		    if (aIsInFirst == bIsInFirst) {
			int vm = -pa.vmul(pb);
			if (vm != 0) {
			    return vm;
			}
			return (mode ? 1 : -1) * (pa.norm() - pb.norm());
		    } else {
			return aIsInFirst ? -1 : 1;
		    }
		}
	    }
	    BaseComparator srcComparator = new BaseComparator(false);
	    Arrays.sort(events, srcComparator);
	    TreeSet<Integer> eventSet = new TreeSet<Integer>(new BaseComparator(true));
	    for (int i = 0; i < n; ++i) {
		Point s = poly[i].sub(src);
		Point f = poly[next[i]].sub(src);
		Point fs = f.sub(s);
		if (s.y == f.y) {
		    continue;
		}
		if (s.y >= 0 && 0 >= f.y) {
		    if (s.vmul(fs) < 0) {
			if (f.y < 0) {
			    eventSet.add(pool[i]);
			} else {
			    eventSet.add(pool[next[i]]);
			}
		    }
		} else if (s.y <= 0 && 0 <= f.y) {
		    if (s.vmul(fs) > 0) {
			if (s.y < 0) {
			    eventSet.add(pool[next[i]]);
			} else {
			    eventSet.add(pool[i]);
			}
		    }
		}
	    }
	    for (int i = 0; i < n - 1; ++i) {
		int cur = events[i];
		if (eventSet.isEmpty() || eventSet.comparator().compare(cur, eventSet.first()) <= 0) {
		    if (!intersect(start, finish, poly[u], poly[cur])) {
			Point pu = poly[prev[u]].sub(poly[u]);
			Point nu = poly[next[u]].sub(poly[u]);
			Point pc = poly[prev[cur]].sub(poly[cur]);
			Point nc = poly[next[cur]].sub(poly[cur]);
			Point cu = poly[cur].sub(poly[u]);
			Point uc = poly[u].sub(poly[cur]);
			int uu = (nu.vmul(cu) > 0 ? 1 : 0) + (cu.vmul(pu) > 0 ? 1 : 0) + (pu.vmul(nu) > 0 ? 1 : 0);
			int cc = (nc.vmul(uc) > 0 ? 1 : 0) + (uc.vmul(pc) > 0 ? 1 : 0) + (pc.vmul(nc) > 0 ? 1 : 0);
			if (uu >= 2 && cc >= 2) {
			    //Oriented!!
			    int startOr = signum(poly[cur].sub(poly[u]).vmul(start.sub(poly[u])));
			    int finishOr = signum(poly[cur].sub(poly[u]).vmul(finish.sub(poly[u])));
			    if (startOr == finishOr) {
				if (startOr > 0) {
				    graph[u].set(cur);
				} else if (startOr < 0) {
			    	    graph[cur].set(u);
				}
			    }
			}
		    }
		}
		eventSet.remove(pool[cur]);
		int prv = prev[cur];
		int nxt = next[cur];
		if (srcComparator.compare(pool[cur], pool[prv]) < 0) {
		    eventSet.add(pool[prv]);
		}
		if (srcComparator.compare(pool[cur], pool[nxt]) < 0) {
		    eventSet.add(pool[nxt]);
		}
	    }
	}
	for (int i = 0; i < n; ++i) {
	    int startOr = signum(poly[next[i]].sub(poly[i]).vmul(start.sub(poly[i])));
	    int finishOr = signum(poly[next[i]].sub(poly[i]).vmul(finish.sub(poly[i])));
	    if (startOr == finishOr) {
		if (startOr > 0) {
		    graph[i].set(next[i]);
    		} else if (startOr < 0) {
		    graph[next[i]].set(i);
		}
	    }
	}
	
	long time1 = System.currentTimeMillis();

	BitSet[] graph2 = new BitSet[n];
	
	for (int i = 0; i < n; ++i) {
	    graph2[i] = new BitSet(n);
	    for (int j = graph[i].nextSetBit(0); j >= 0; j = graph[i].nextSetBit(j + 1)) {
		graph2[i].or(graph[j]);
	    }
	}
	BitSet[] rgraph = new BitSet[n];
	for (int i = 0; i < n; ++i) {
	    rgraph[i] = new BitSet(n);
	    for (int j = 0; j < n; ++j) {
		if (graph[j].get(i)) {
		    rgraph[i].set(j);
		}
	    }
	}
	
	long time2 = System.currentTimeMillis();
	
	System.err.println("Visibility graph building: " + (time1 - time0));
	System.err.println("Graph2 and RGraph building: " + (time2 - time1));
	
	PrintWriter out = new PrintWriter("interfering.out");
	for (int i = 0; i < n; ++i) {
	    BitSet test = (BitSet) rgraph[i].clone();
	    test.and(graph2[i]);
	    if (test.cardinality() > 0) {
		//Yes!!
		int p0 = i;
		int p2 = test.nextSetBit(0);
		BitSet test1 = (BitSet) rgraph[p2].clone();
		test1.and(graph[p0]);
		int p1 = test1.nextSetBit(0);
		if (square > 0) {
		    out.println((p0 + 1) + " " + (p1 + 1) + " " + (p2 + 1));
		} else {
		    out.println((n - p0) + " " + (n - p1) + " " + (n - p2));
		}
		out.close();
		return;
	    }
	}
	
	out.println("Impossible");
	out.close();
    }
}
