import java.io.*;
import java.util.*;

//Problem "New Roads"
//11th Internet Olympiad, season 2007-2008, basic level.
//Problem Author: Maxim Buzdalov, buzdalov@rain.ifmo.ru
//Solution Author: Maxim Buzdalov, buzdalov@rain.ifmo.ru

//The slow solution, uses time of O(E + maxSCC^2).

public class newroads_mb_tl implements Runnable {
    static class IntReader {
        String string;
        
        public IntReader(String s) {
            string = s;
        }
        
        public int first() {
            return Integer.parseInt(string.substring(0, string.indexOf(' ')));
        }
        
        public int second() {
            return Integer.parseInt(string.substring(string.indexOf(' ') + 1));
        }
    }
    
    static class Pair implements Comparable<Pair> {
        int first, second;
        
        public Pair(int f, int s) {
            first = f;
            second = s;
        }
        
        public int compareTo(Pair that) {
            return first == that.first ? second - that.second : first - that.first;
        }
        
        public int hashCode() {
            return first * 223 + second * 33282829;
        }
        
        public boolean equals(Object o) {
            return ((Pair)o).compareTo(this) == 0;
        }
    }
    
    int[] order;
    int[] color;
    int time;
    boolean[] usedFw;
    
    ArrayList<Integer>[] fw, bw;
    
    void dfsFw(int start) {
        usedFw[start] = true;
        for (int next : fw[start]) {
            if (!usedFw[next]) {
                dfsFw(next);
            }
        }
        order[time++] = start;
    }
    
    void dfsBw(int start, int col) {
        color[start] = col;
        for (int next : bw[start]) {
            if (color[next] == 0) {
                dfsBw(next, col);
            }
        }
    }
    
    public void run() {
        try {
            BufferedReader in = new BufferedReader(new FileReader("newroads.in"));
            IntReader bounds = new IntReader(in.readLine());
            
            int n = bounds.first(), m = bounds.second();
            
            assert 1 <= n && n <= 100000 : "N is out of bounds";
            assert 0 <= m && m <= 200000 : "M is out of bounds";
            
            order = new int[n];
            color = new int[n];
            fw = new ArrayList[n];
            bw = new ArrayList[n];
            usedFw = new boolean[n];
            for (int i = 0; i < n; ++i) {
                fw[i] = new ArrayList<Integer>();
                bw[i] = new ArrayList<Integer>();
            }
            
            HashSet<Pair> edges = new HashSet<Pair>();
        
            for (int i = 0; i < m; ++i) {
                IntReader ir = new IntReader(in.readLine());
                int start = ir.first() - 1;
                int finish = ir.second() - 1;
                edges.add(new Pair(start, finish));
                assert 0 <= start && start < n : "Start is out of bounds";
                assert 0 <= finish && finish < n : "Finish is out of bounds";
                fw[start].add(finish);
                bw[finish].add(start);
            }
            
            for (int i = 0; i < n; ++i) {
                if (!usedFw[i]) {
                    dfsFw(i);
                }
            }
            
            int colorCount = 0;
            for (int i = n - 1; i >= 0; --i) {
                int start = order[i];
                if (color[start] == 0) {
                    dfsBw(start, ++colorCount);
                }
            }
            
            ArrayList<Integer>[] colored = new ArrayList[colorCount];
            for (int i = 0; i < colorCount; ++i) {
                colored[i] = new ArrayList<Integer>();
            }
            for (int i = 0; i < n; ++i) {
                colored[color[i] - 1].add(i);
            }
            
            long necessaryEdges = 0;
            for (int c = 0; c < colorCount; ++c) {
                for (int ind1 = colored[c].size() - 1; ind1 >= 0; --ind1) {
                    for (int ind2 = colored[c].size() - 1; ind2 >= 0; --ind2) {
                        if (ind1 != ind2) {	
                            Pair p = new Pair(colored[c].get(ind1), colored[c].get(ind2));
                            if (!edges.contains(p)) {
                                ++necessaryEdges;
                            }
                        }
                    }
                }
            }
            
            PrintWriter out = new PrintWriter("newroads.out");
            out.println(necessaryEdges);
            out.close();
        } catch (Throwable ex) {
            ex.printStackTrace();
            System.exit(1);
        }
    }
    
    public static void main(String[] args) {
        new Thread(new newroads_mb_tl()).start();
    }
}
