import java.io.*;
import java.util.*;

//Problem "Union of parallelepipeds - 2"
//11th Internet Olympiad, advanced level, season 2007-2008
//Problem Author: Fedor Tsarev, tsarev@rain.ifmo.ru
//Solution Author: Maxim Buzdalov, buzdalov@rain.ifmo.ru

//A "geometric" solution: all the possible space subdivisions are considered,
//a decision of being included in the union is made for each of them.

//Complexity: O(8 * N^4)

public class union2_mb {
    static class PP {
        int minX, minY, minZ, maxX, maxY, maxZ;
        
        public PP(int aX, int aY, int aZ, int bX, int bY, int bZ) {
            minX = Math.min(aX, bX);
            minY = Math.min(aY, bY);
            minZ = Math.min(aZ, bZ);
            maxX = Math.max(aX, bX);
            maxY = Math.max(aY, bY);
            maxZ = Math.max(aZ, bZ);
        }
        
        public boolean containsWholeCube(int x, int y, int z) {
            return minX <= x && x < maxX && minY <= y && y < maxY && minZ <= z && z < maxZ;
        }
    }
    
    public static void main(String[] args) throws IOException {
        Scanner in = new Scanner(new File("union2.in"));
        int n = in.nextInt();
        PP[] pps = new PP[n];
        TreeSet<Integer> xs = new TreeSet<Integer>();
        TreeSet<Integer> ys = new TreeSet<Integer>();
        TreeSet<Integer> zs = new TreeSet<Integer>();
        for (int i = 0; i < n; ++i) {
            pps[i] = new PP(in.nextInt(), in.nextInt(), in.nextInt(), in.nextInt(), in.nextInt(), in.nextInt());
            xs.add(pps[i].minX);
            xs.add(pps[i].maxX);
            ys.add(pps[i].minY);
            ys.add(pps[i].maxY);
            zs.add(pps[i].minZ);
            zs.add(pps[i].maxZ);
        }
        in.close();
        
        Integer[] xx = xs.toArray(new Integer[xs.size()]);
        Integer[] yy = ys.toArray(new Integer[xs.size()]);
        Integer[] zz = zs.toArray(new Integer[xs.size()]);
        
        long volume = 0;
        for (int x = 0; x + 1 < xx.length; ++x) {
            for (int y = 0; y + 1 < yy.length; ++y) {
                for (int z = 0; z + 1 < zz.length; ++z) {
                    boolean contain = false;
                    for (int t = 0; !contain && t < n; ++t) {
                        contain |= pps[t].containsWholeCube(xx[x], yy[y], zz[z]);
                    }
                    if (contain) {
                        volume += (long) (xx[x + 1] - xx[x]) * (long) (yy[y + 1] - yy[y]) * (long) (zz[z + 1] - zz[z]);
                    }
                }
            }
        }
        
        PrintWriter out = new PrintWriter("union2.out");
        out.println(volume);
        out.close();
    }
}
