import java.io.*;
import java.util.*;

//Problem "Union of parallelepipeds - 2"
//11th Internet Olympiad, advanced level, season 2007-2008
//Problem Author: Fedor Tsarev, tsarev@rain.ifmo.ru
//Solution Author: Maxim Buzdalov, buzdalov@rain.ifmo.ru

//A "combinatoric" solution: using an inclusion-exclusion formula.

public class union2_mb2 {
    static class PP {
        int minX, minY, minZ, maxX, maxY, maxZ;
        
        public PP(int aX, int aY, int aZ, int bX, int bY, int bZ) {
            minX = Math.min(aX, bX);
            minY = Math.min(aY, bY);
            minZ = Math.min(aZ, bZ);
            maxX = Math.max(aX, bX);
            maxY = Math.max(aY, bY);
            maxZ = Math.max(aZ, bZ);
        }
        
        public PP() {
            minY = minZ = minX = Integer.MIN_VALUE;
            maxX = maxY = maxZ = Integer.MAX_VALUE;
        }
        
        public void intersect(PP pp) {
            minX = Math.max(minX, pp.minX);
            minY = Math.max(minY, pp.minY);
            minZ = Math.max(minZ, pp.minZ);
            maxX = Math.min(maxX, pp.maxX);
            maxY = Math.min(maxY, pp.maxY);
            maxZ = Math.min(maxZ, pp.maxZ);
            if (minX > maxX) {
                minX = maxX;
            }
            if (minY > maxY) {
                minY = maxY;
            }
            if (minZ > maxZ) {
                minZ = maxZ;
            }
        }
    }
    
    public static void main(String[] args) throws IOException {
        Scanner in = new Scanner(new File("union2.in"));
        int n = in.nextInt();
        PP[] pps = new PP[n];
        for (int i = 0; i < n; ++i) {
            pps[i] = new PP(in.nextInt(), in.nextInt(), in.nextInt(), in.nextInt(), in.nextInt(), in.nextInt());
        }
        in.close();
        
        PP[] all = new PP[1 << n];
        
        for (int i = 0; i < 1 << n; ++i) {
            all[i] = new PP();
            for (int j = 0; j < n; ++j) {
                if ((i & (1 << j)) != 0) {
                    all[i].intersect(pps[j]);
                }
            }
//            System.out.println(all[i].minX + "--" + all[i].maxX + ", " + all[i].minY + "--" + all[i].maxY + ", " + all[i].minZ + "--" + all[i].maxZ);
        }
        
        long volume = 0;
        
        for (int i = 1; i < 1 << n; ++i) {
            long lv = (long) (all[i].maxX - all[i].minX) 
                    * (long) (all[i].maxY - all[i].minY) 
                    * (long) (all[i].maxZ - all[i].minZ);
            volume += lv * (2 * (Integer.bitCount(i) % 2) - 1);
        }
        
        PrintWriter out = new PrintWriter("union2.out");
        out.println(volume);
        out.close();
    }
}
