import java.util.*;
import java.io.*;

public class lateagain_as implements Runnable {

    final double EPS = 1e-7;

    class Edge {
        int s;
        int t;
        int c;
        boolean m;
        boolean d;

        Edge(int s, int t, int c, boolean m) {
            this.s = s;
            this.t = t;
            this.c = c;
            this.m = m;
        }
    }

    public void solve() throws IOException {
        Scanner in = new Scanner(new File("lateagain.in"));
        PrintWriter out = new PrintWriter("lateagain.out");

        int n = in.nextInt();
        assert 2 <= n && n <= 1000;
        int en = in.nextInt();
        assert 1 <= en && en <= 20000;
        ArrayList<Edge>[] edges = new ArrayList[n];
        for (int i = 0; i < n; i++) {
            edges[i] = new ArrayList<Edge>();
        }
        Edge[] es = new Edge[2 * en];
        boolean[][] was = new boolean[n][n];
        for (int i = 0; i < en; i++) {
            int x = in.nextInt() - 1;
            int y = in.nextInt() - 1;
            assert x != y;
            assert !was[x][y];
            was[x][y] = was[y][x] = true;
            int c = in.nextInt();
            assert 0 < c && c <= 10000;
            es[2 * i] = new Edge(x, y, c, false);
            edges[x].add(es[2 * i]);
            es[2 * i + 1] = new Edge(y, x, c, false);
            edges[y].add(es[2 * i + 1]);
        }

        int len = in.nextInt();
        boolean[] wpath = new boolean[en];
        int pos = 0;
        for (int i = 0; i < len; i++) {
            int k = in.nextInt() - 1;
            assert !wpath[k];
            wpath[k] = true;
            
            es[2 * k].d = true;
            es[2 * k + 1].d = true;

            int t = 2 * k;
            if (es[t].s != pos) {
                t = t + 1;
            }
            assert es[t].s == pos;
            es[t].m = true;
            pos = es[t].t;
        }
        assert pos == n - 1;

        double l = 0;
        double r = 2e7;
        for (int iter = 0; iter < 50; iter++) {
            double m = (l + r) / 2;

            double[] d = new double[n];
            Arrays.fill(d, Double.POSITIVE_INFINITY);
            boolean[] u = new boolean[n];
            d[0] = 0;
            while (true) {
                int k = -1;
                for (int i = 0; i < n; i++) {
                    if (!u[i] && (k == -1 || d[i] < d[k])) {
                        k = i;
                    }
                }
                if (k == -1) {
                    break;
                }
                u[k] = true;
                for (Edge e : edges[k]) {
                    double w = e.c + m;
                    if (e.d) {
                        w = e.c - m;
                        if (w < 1) {
                            w = 1;
                        }
                    }
                    if (d[k] + w < d[e.t]) {
                        d[e.t] = d[k] + w;
                    }
                }
            }
            boolean ok = true;
            for (Edge e : es) {
                if (e.m) {
                    double w = e.c - m;
                    if (w < 1) {
                        w = 1;
                    }
                    if (d[e.s] + w > d[e.t] + EPS) {
                        ok = false;
                    }
                }
            }
            if (ok) {
                r = m;
            } else {
                l = m;
            }
        }

        out.printf("%.7f\n", l);
        for (int i = 0; i < en; i++) {
            double w = es[2 * i].c + l;
            if (es[2 * i].d) {
                w = es[2 * i].c - l;
                if (w < 1) {
                    w = 1;
                }
            }
            out.printf("%.7f ", w);
        }
        out.println();

        in.close();
        out.close();
    }

    public void run() {
        try {
            solve();
        } catch (IOException e) {
        }
    }

    public static void main(String[] arg) {
        Locale.setDefault(Locale.US);
        new Thread(new lateagain_as()).start();
    }
}