import java.io.*;
import java.util.*;

@SuppressWarnings("unchecked")
public class roadsigns_as implements Runnable {
    class Edge {
        int s;
        int t;
        int i;
        int c;
        boolean u;
        Edge r;

        Edge(int s, int t, int i) {
            this.s = s;
            this.t = t;
            this.i = i;
            c = -1;
        }

        public String toString() {
            return s + "->" + t + " (" + c + ")";
        }
    }

    int n;
    int m;
    int deg;
    ArrayList<Edge>[] edges;
    SortedSet<Integer>[] free;

    boolean checkIntergrity() {
        SortedSet<Integer>[] trueFree = new SortedSet[n];
        for (int i = 0; i < n; i++) {
            trueFree[i] = new TreeSet<Integer>();
            for (int j = 0; j <= deg; j++) {
                trueFree[i].add(j);
            }
            for (Edge e : edges[i]) {
                if (e.c != -1) {
                    trueFree[i].remove(e.c);
                }
            }
            if (!free[i].equals(trueFree[i])) {
                return false;
            }
        }

        return true;
    }

    boolean swap(int x, int c, int d, Edge enter) {
        for (Edge e : edges[x]) {
            if (e.c == c && e != enter) {
                e.c = e.r.c = d;
                swap(e.t, d, c, e.r);
                return true;
            }
        }
        if (enter != null) {
            assert free[x].contains(c);
            assert !free[x].contains(d);
            free[x].remove(c);
            free[x].add(d);
        }
        return false;
    }

    public void solve() throws IOException {
        Scanner in = new Scanner(new File("roadsigns.in"));
        PrintWriter out = new PrintWriter(new File("roadsigns.out"));

        n = in.nextInt();
        m = in.nextInt();
        deg = in.nextInt();
        edges = new ArrayList[n];
        for (int i = 0; i < n; i++) {
            edges[i] = new ArrayList<Edge>();
        }
        for (int i = 0; i < m; i++) {
            int x = in.nextInt() - 1;
            int y = in.nextInt() - 1;
            Edge ef = new Edge(x, y, i);
            Edge er = new Edge(y, x, i);
            ef.r = er;
            er.r = ef;
            edges[x].add(ef);
            edges[y].add(er);
        }

        free = new SortedSet[n];
        for (int i = 0; i < n; i++) {
            free[i] = new TreeSet<Integer>();
            for (int j = 0; j <= deg; j++) {
                free[i].add(j);
            }
        }

        for (int i = 0; i < n; i++) {
            color:
            for (Edge e : edges[i]) {
                if (e.c == -1) {
                    for (int j = 0; j <= deg; j++) {
                        if (free[e.s].contains(j) && free[e.t].contains(j)) {
                            e.c = e.r.c = j;
                            free[e.s].remove(j);
                            free[e.t].remove(j);
                            continue color;
                        }
                    }

                    System.out.println("Using fan");

                    ArrayList<Edge> fan = new ArrayList<Edge>();
                    fan.add(e);
                    e.u = true;

                    Edge last = e;
                    while (true) {
                        Edge found = null;
                        for (Edge ef : edges[i]) {
                            if (!ef.u && ef.c != -1 && free[last.t].contains(ef.c)) {
                                found = ef;
                                break;
                            }
                        }
                        if (found == null) {
                            break;
                        }
                        fan.add(found);
                        found.u = true;
                        last = found;
                    }

                    int c = free[i].first();
                    int d = free[last.t].first();

                    if (c != d) {
                        if (swap(i, d, c, null)) {
                            free[i].remove(c);
                            free[i].add(d);
                        }
                        checkIntergrity();
                    }

                    int j;

                    Edge nxt = fan.get(0);
                    for (j = 0; j < fan.size(); j++) {
                        if (free[nxt.t].contains(d)) {
                            nxt.c = nxt.r.c = d;
                            free[nxt.t].remove(d);
                            free[i].remove(d);
                            break;
                        }

                        Edge cur = nxt;
                        nxt = fan.get(j + 1);

                        assert !free[cur.t].contains(cur.c);
                        assert free[cur.t].contains(nxt.c);
                        if (cur.c != -1) {
                            free[cur.t].add(cur.c);
                        }
                        free[cur.t].remove(nxt.c);
                        free[nxt.t].add(nxt.c);
                        cur.c = cur.r.c = nxt.c;
                        nxt.c = nxt.r.c = -1;
                        assert checkIntergrity();

                    }

                    for (Edge ee : edges[i]) {
                        ee.u = false;
                    }
                }
            }

            assert checkIntergrity();
        }

        int[] c = new int[m];
        for (int i = 0; i < n; i++) {
            for (Edge e : edges[i]) {
                c[e.i] = e.c + 1;
            }
        }

        for (int i = 0; i < m; i++) {
            out.print(c[i] + " ");
        }
        out.println();

        in.close();
        out.close();
    }

    public void run() {
        try {
            solve();
        } catch (IOException e) {
            System.exit(64);
        }
    }

    public static void main(String[] arg) throws IOException {
        new Thread(new roadsigns_as()).start();
    }
}
