import java.util.*;
import java.io.*;

public class nothingontv_as implements Runnable {
    BufferedReader in;
    StringTokenizer st;

    int nextInt() {
        while (st == null || !st.hasMoreTokens()) {
            try {
                st = new StringTokenizer(in.readLine());
            } catch (IOException e) {
            }
        }
        return Integer.parseInt(st.nextToken());
    }

    class Point {
        final double x;
        final double y;
        final double l;
        int id;

        public Point(double x, double y) {
            this.x = x;
            this.y = y;
            this.l = x * x + y * y;
        }

        @Override
        public String toString() {
            return "(" + x + "," + y + ")";
        }

        public boolean closeTo(Point p1) {
            return Math.sqrt((x - p1.x) * (x - p1.x) + (y - p1.y) * (y - p1.y)) < EPS;
        }
    }

    class Node {
        Point v;
        int y;
        int sz;

        Node l;
        Node r;

        public Node(Point v, int y, Node l, Node r) {
            this.v = v;
            this.y = y;
            this.l = l;
            this.r = r;
        }
    }

    void relax(Node n) {
        n.sz = 1 + (n.l == null ? 0 : n.l.sz) + (n.r == null ? 0 : n.r.sz);
    }

    int leftSize(Node n) {
        if (n.l == null) {
            return 0;
        } else {
            return n.l.sz;
        }
    }

    Node[] sp;

    void split(Node t, int s) {
        if (t == null) {
            sp[0] = sp[1] = null;
            return;
        }

        int ls = leftSize(t);
        if (s <= ls) {
            split(t.l, s);
            t.l = sp[1];
            relax(t);
            sp[1] = t;
        } else {
            split(t.r, s - ls - 1);
            t.r = sp[0];
            relax(t);
            sp[0] = t;
        }
        assert (s == 0 && sp[0] == null) || sp[0].sz == s;
    }

    Node merge(Node tl, Node tr) {
        if (tl == null) {
            return tr;
        } else if (tr == null) {
            return tl;
        } else if (tl.y < tr.y) {
            tl.r = merge(tl.r, tr);
            relax(tl);
            return tl;
        } else {
            tr.l = merge(tl, tr.l);
            relax(tr);
            return tr;
        }
    }

    Node insert(Node t, int p, Point v, int y) {
        if (t == null || y < t.y) {
            split(t, p);
            Node nx = new Node(v, y, sp[0], sp[1]);
            relax(nx);
            return nx;
        } else {
            int ls = leftSize(t);
            if (p <= ls) {
                t.l = insert(t.l, p, v, y);
                relax(t);
                return t;
            } else {
                t.r = insert(t.r, p - ls - 1, v, y);
                relax(t);
                return t;
            }
        }
    }

    Node delete(Node t, int p) {
        int ls = leftSize(t);
        if (p < ls) {
            t.l = delete(t.l, p);
            relax(t);
            return t;
        } else if (p > ls) {
            t.r = delete(t.r, p - ls - 1);
            relax(t);
            return t;
        } else {
            t = merge(t.l, t.r);
            return t;
        }
    }

    Point get(Node t, int p) {
        int ls = leftSize(t);
        if (p < ls) {
            return get(t.l, p);
        } else if (p > ls) {
            return get(t.r, p - ls - 1);
        } else {
            return t.v;
        }
    }

    Point intersect(double a1, double b1, double c1, Point p1, Point p2) {
        c1 = -c1;
        double a2 = p1.y - p2.y;
        double b2 = p2.x - p1.x;
        double c2 = a2 * p1.x + b2 * p1.y;

        double d = a1 * b2 - a2 * b1;
        double xi = (c1 * b2 - c2 * b1) / d;
        double yi = (a1 * c2 - a2 * c1) / d;

        return new Point(xi, yi);
    }

    boolean between(double x, double y, double z) {
        return
                (x < y - EPS && y < z - EPS) ||
                (z < y - EPS && y < x - EPS);
    }

    final static long MAX = 30001;
    final static double EPS = 1e-6;

    public void solve() throws IOException {
        in = new BufferedReader(new FileReader("nothingontv.in"));
        PrintWriter out = new PrintWriter("nothingontv.out");

        int n = nextInt();
        Point[] p = new Point[n];
        for (int i = 0; i < n; i++) {
            p[i] = new Point(nextInt(), nextInt());
            p[i].id = i + 1;
        }

        Arrays.sort(p, new Comparator<Point>() {
            public int compare(Point o1, Point o2) {
                return o1.x < o2.x ? -1 : o1.x > o2.x ? 1 : o1.y < o2.y ? -1 : o1.y > o2.y ? 1 : 0;
            }
        });
        for (int i = 0; i < n - 1; i++) {
            if (p[i].x == p[i+1].x && p[i].y == p[i + 1].y) {
                assert false;
            }
        }
        Arrays.sort(p, new Comparator<Point>() {
            public int compare(Point o1, Point o2) {
                return o1.l < o2.l ? -1 : o1.l > o2.l ? 1 : 0;
            }
        });

        Random rand = new Random(298472390);
        sp = new Node[2];
        Node root = null;
        root = insert(root, 0, new Point(-MAX, -MAX), rand.nextInt());
        root = insert(root, 1, new Point(+MAX, -MAX), rand.nextInt());
        root = insert(root, 2, new Point(+MAX, +MAX), rand.nextInt());
        root = insert(root, 3, new Point(-MAX, +MAX), rand.nextInt());

        ArrayList<Integer> answer = new ArrayList<Integer>();
        for (int i = 0; i < n; i++) {
            double a = p[i].x;
            double b = p[i].y;
            double c = -(a * p[i].x + b * p[i].y);

            int[] bind = new int[2];
            for (int j = 0; j < 2; j++) {
                int l = 0;
                Point lp = get(root, l);
                Point lp1 = get(root, l + 1);
                boolean linc = a * lp1.x + b * lp1.y >= a * lp.x + b * lp.y;
                int r = root.sz;
                while (l < r - 1) {
                    int m = (l + r) / 2;
                    Point mp = get(root, m);
                    Point mp1 = get(root, (m + 1) % root.sz);
                    boolean minc = a * mp1.x + b * mp1.y >= a * mp.x + b * mp.y;
                    boolean mgtl = a * mp.x + b * mp.y >= a * lp.x + b * lp.y;
                    if (linc) {
                        if (mgtl) {
                            if (minc) {
                                l = m;
                                linc = minc;
                                lp = mp;
                                lp1 = mp1;
                            } else {
                                r = m;
                            }
                        } else {
                            r = m;
                        }
                    } else {
                        if (mgtl) {
                            if (minc) {
                                l = m;
                                linc = minc;
                                lp = mp;
                                lp1 = mp1;
                            } else {
                                r = m;
                            }
                        } else {
                            l = m;
                            linc = minc;
                            lp = mp;
                            lp1 = mp1;
                        }
                    }
                }

                bind[j] = (l + 1) % root.sz;
                a = -a;
                b = -b;
                c = -c;
            }

//            System.out.println("----> " + p[i]);

//            System.out.println("+++ " + get(root, bind[0]));
//            System.out.println("+++ " + get(root, bind[1]));

            Point mx = get(root, bind[0]);
            if (a * mx.x + b * mx.y + c < EPS) {
//            	System.out.println("All negative");
                continue;
            }

            int[] ind = new int[2];
            for (int j = 0; j < 2; j++) {
                int l = bind[j];
                int r = bind[1 - j];
                if (r < l) {
                    r = r + root.sz;
                }
                while (l < r - 1) {
                    int m = (l + r) / 2;
                    Point pm = get(root, m % root.sz);
                    boolean mpos = a * pm.x + b * pm.y + c >= -EPS;
                    if (mpos) {
                        l = m;
                    } else {
                        r = m;
                    }
                }

                ind[j] = l % root.sz;
                a = -a;
                b = -b;
                c = -c;
            }

            Point p1 = get(root, ind[0]);
            Point p2 = get(root, ind[1]);

//            System.out.println("*** " + p1);
//            System.out.println("*** " + p2);

            Point p1n = get(root, (ind[0] + 1) % root.sz);
            Point p2n = get(root, (ind[1] + 1) % root.sz);


            assert !p1n.closeTo(p1);
            assert !p2n.closeTo(p2);

            Point ip1 = intersect(a, b, c, p1, p1n);
            Point ip2 = intersect(a, b, c, p2, p2n);

            if (between(ip1.x, p[i].x, ip2.x) || between(ip1.y, p[i].y, ip2.y)) {
                answer.add(p[i].id);
//                System.out.println("A " + p[i].id + p[i]);
            } else {
//                System.out.println("D " + p[i].id + p[i]);
                continue;
            }

            assert ind[0] != ind[1];
            if (ind[1] < ind[0]) {
                for (int j = ind[1]; j < ind[0]; j++) {
                    root = delete(root, ind[1] + 1);
                }
                root = insert(root, ind[1] + 1, ip2, rand.nextInt());
                root = insert(root, ind[1] + 2, ip1, rand.nextInt());
            } else {
                int sz = root.sz;
                for (int j = ind[1] + 1; j < sz; j++) {
                    root = delete(root, ind[1] + 1);
                }
                for (int j = 0; j <= ind[0]; j++) {
                    root = delete(root, 0);
                }
                root = insert(root, 0, ip2, rand.nextInt());
                root = insert(root, 1, ip1, rand.nextInt());
            }

//            for (int j = 0; j < root.sz; j++) {
//                System.out.println(get(root, j));
//            }
//            System.out.println("---");
        }

        System.out.println(root.sz);

        Collections.sort(answer);
        out.println(answer.size());
        for (int i : answer) {
            out.print(i + " ");
        }
        out.println();

        in.close();
        out.close();
    }

    public void run() {
        try {
            solve();
        } catch (IOException e) {
        }
    }

    public static void main(String[] arg) {
        new Thread(new nothingontv_as()).start();
    }
}
