import java.io.*;
import java.math.BigInteger;
import java.util.*;

//Problem "The segment and the circles"
//5th Internet Olympiad, advanced level, season 2008-2009
//Problem Author:  Vladimir Ulyantsev
//Solution Author: Vladislav Isenbaev, isenbaev@rain.ifmo.ru

public class circles_vi implements Runnable {

    private BufferedReader in;
    private StringTokenizer st;
    private PrintWriter out;
    
    static class Vector {
        long x, y;
        
        Vector(long x, long y) {
            this.x = x;
            this.y = y;
        }
        
        long len2() {
            return x * x + y * y;
        }
        
        Vector diff(Vector b) {
            return new Vector(x - b.x, y - b.y);
        }
    }
    
    static long sMul(Vector a, Vector b) {
        return a.x * b.x + a.y * b.y;
    }
    
    static long vMul(Vector a, Vector b) {
        return a.x * b.y - a.y * b.x;
    }
    
    final BigInteger TWO = BigInteger.valueOf(2);
    
    boolean isSquare(BigInteger v) {
        BigInteger l = BigInteger.ONE.negate();
        BigInteger r = BigInteger.ONE;
        while (r.multiply(r).compareTo(v) < 0) {
            r = r.add(r);
        }
        while (r.subtract(l).compareTo(BigInteger.ONE) > 0) {
            BigInteger x = l.add(r).divide(TWO);
            if (x.multiply(x).compareTo(v) < 0) {
                l = x;
            } else {
                r = x;
            }
        }
        return r.multiply(r).compareTo(v) == 0;
    }
    
    long minContainsNI(BigInteger v) {
        BigInteger l = BigInteger.ZERO;
        BigInteger r = BigInteger.ONE;
        while (r.multiply(r).compareTo(v) <= 0) {
            r = r.add(r);
        }
        while (r.subtract(l).compareTo(BigInteger.ONE) > 0) {
            BigInteger x = l.add(r).divide(TWO);
            if (x.multiply(x).compareTo(v) <= 0) {
                l = x;
            } else {
                r = x;
            }
        }
        return r.longValue();
    }
    
    long minContainsI(BigInteger nom, BigInteger denom) {
        BigInteger l = BigInteger.ONE.negate();
        BigInteger r = BigInteger.ONE;
        while (r.multiply(r).multiply(denom).compareTo(nom) <= 0) {
            r = r.add(r);
        }
        while (r.subtract(l).compareTo(BigInteger.ONE) > 0) {
            BigInteger x = l.add(r).divide(TWO);
            if (x.multiply(x).multiply(denom).compareTo(nom) < 0) {
                l = x;
            } else {
                r = x;
            }
        }
        return r.longValue();
    }
    
    void solve() throws IOException {
        Vector a = new Vector(nextLong(), nextLong());
        Vector b = new Vector(nextLong(), nextLong());
        Vector vec = b.diff(a);
        long u = a.len2();
        long v = b.len2();
        if (sMul(a, vec) < 0 && sMul(b, vec) > 0) {
            BigInteger wn = BigInteger.valueOf(vMul(a, vec));
            wn = wn.multiply(wn);
            BigInteger wd = BigInteger.valueOf(vec.len2());
            int corr = wd.signum() > 0 && wn.mod(wd).signum() == 0 && isSquare(wn.divide(wd)) ? 1 : 0;
            if (wn.signum() == 0) {
                corr += 1;
            }
            out.println(
                    +minContainsNI(BigInteger.valueOf(u))
                    +minContainsNI(BigInteger.valueOf(v))
                    -2 * minContainsI(wn, wd)
                    -corr
                );
        } else {
            int corr = u == 0 || v == 0 ? 1 : 0;
            out.println(
                    +minContainsNI(BigInteger.valueOf(Math.max(u, v))) 
                    -minContainsI(BigInteger.valueOf(Math.min(u, v)), BigInteger.ONE)
                    -corr
                );
        }
    }
    
    public void run() {
        try {
            Locale.setDefault(Locale.US);
            
            in = new BufferedReader(new FileReader("circles.in"));
            st = new StringTokenizer("");
            out = new PrintWriter("circles.out");
            
            solve();
            
            out.close();
        } catch (Exception ex) {
            ex.printStackTrace();
            System.exit(-1);
        }
    }
    
    public static void main(String[] args) {
        new Thread(new circles_vi()).start();
    }

    String next() throws IOException {
        while (!st.hasMoreTokens()) {
            String line = in.readLine();
            if (line == null) {
                return null;
            }
            st = new StringTokenizer(line);
        }
        return st.nextToken();
    }
    
    int nextInt() throws IOException {
        return Integer.parseInt(next());
    }
    
    long nextLong() throws IOException {
        return Long.parseLong(next());
    }
    
    double nextDouble() throws IOException {
        return Double.parseDouble(next());
    }
}
